{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_name = function(named_input, suffix, ext) { suffix = suffix || \"\"; ext = ext || \"\"; if (Array.isArray(named_input) && named_input.length > 0){ return named_input[0].location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+suffix+ext; } else { return named_input.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+suffix+ext; } };"
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Chromosome length file for reference genome",
                    "doc": "Chromosome length file for reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "label": "Input FASTQ file(s)",
                    "doc": "Input FASTQ file or array of files",
                    "id": "#allele-alignreads-se-pe.cwl/fastq_files"
                },
                {
                    "type": "File",
                    "label": "HAL file",
                    "doc": "HAL file that includes strain information",
                    "id": "#allele-alignreads-se-pe.cwl/hal_file"
                },
                {
                    "type": "Directory",
                    "label": "STAR indices folder for insilico genome",
                    "doc": "Path to STAR generated indices folder for insilico genome",
                    "id": "#allele-alignreads-se-pe.cwl/insilico_star_indices_folder"
                },
                {
                    "type": "string",
                    "label": "Reference strain name",
                    "doc": "Reference strain name to be projected to",
                    "id": "#allele-alignreads-se-pe.cwl/ref_strain"
                },
                {
                    "type": "Directory",
                    "label": "STAR indices folder for reference genome",
                    "doc": "Path to STAR generated indices folder for reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/reference_star_indices_folder"
                },
                {
                    "type": "string",
                    "label": "I strain name",
                    "doc": "First strain name",
                    "id": "#allele-alignreads-se-pe.cwl/strain1"
                },
                {
                    "type": "string",
                    "label": "II strain name",
                    "doc": "Second strain name",
                    "id": "#allele-alignreads-se-pe.cwl/strain2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "id": "#allele-alignreads-se-pe.cwl/threads"
                }
            ],
            "steps": [
                {
                    "run": "#star-alignreads.cwl",
                    "in": [
                        {
                            "source": "#allele-alignreads-se-pe.cwl/insilico_star_indices_folder",
                            "id": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/genomeDir"
                        },
                        {
                            "source": [
                                "#allele-alignreads-se-pe.cwl/strain1",
                                "#allele-alignreads-se-pe.cwl/strain2"
                            ],
                            "valueFrom": "$(default_output_name(inputs.readFilesIn, \"_\"+self.join(\"_\"), \".\"))",
                            "id": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/outFileNamePrefix"
                        },
                        {
                            "default": 1,
                            "id": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/outFilterMultimapNmax"
                        },
                        {
                            "default": [
                                "SAM"
                            ],
                            "id": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/outSAMtype"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/fastq_files",
                            "id": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/readFilesIn"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/threads",
                            "id": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/threads"
                        }
                    ],
                    "out": [
                        "#allele-alignreads-se-pe.cwl/insilico_star_aligner/aligned_file",
                        "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_final",
                        "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_out",
                        "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_progress",
                        "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_std",
                        "#allele-alignreads-se-pe.cwl/insilico_star_aligner/uniquely_mapped_reads_number"
                    ],
                    "id": "#allele-alignreads-se-pe.cwl/insilico_star_aligner"
                },
                {
                    "run": "#allele-process-reference.cwl",
                    "in": [
                        {
                            "source": "#allele-alignreads-se-pe.cwl/reference_star_aligner/aligned_file",
                            "id": "#allele-alignreads-se-pe.cwl/reference_process/bam_file"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/chrom_length_file",
                            "id": "#allele-alignreads-se-pe.cwl/reference_process/chrom_length_file"
                        },
                        {
                            "source": [
                                "#allele-alignreads-se-pe.cwl/fastq_files",
                                "#allele-alignreads-se-pe.cwl/reference_star_aligner/uniquely_mapped_reads_number"
                            ],
                            "valueFrom": "${ return (Array.isArray(self[0]) && self[0].length>1)?2*self[1]:self[1]; }",
                            "id": "#allele-alignreads-se-pe.cwl/reference_process/mapped_reads_number"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/fastq_files",
                            "valueFrom": "$(default_output_name(self))",
                            "id": "#allele-alignreads-se-pe.cwl/reference_process/output_file_prefix"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/threads",
                            "id": "#allele-alignreads-se-pe.cwl/reference_process/threads"
                        }
                    ],
                    "out": [
                        "#allele-alignreads-se-pe.cwl/reference_process/bambai_pair",
                        "#allele-alignreads-se-pe.cwl/reference_process/bigwig_file"
                    ],
                    "id": "#allele-alignreads-se-pe.cwl/reference_process"
                },
                {
                    "run": "#star-alignreads.cwl",
                    "in": [
                        {
                            "source": "#allele-alignreads-se-pe.cwl/reference_star_indices_folder",
                            "id": "#allele-alignreads-se-pe.cwl/reference_star_aligner/genomeDir"
                        },
                        {
                            "default": 1,
                            "id": "#allele-alignreads-se-pe.cwl/reference_star_aligner/outFilterMultimapNmax"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/fastq_files",
                            "id": "#allele-alignreads-se-pe.cwl/reference_star_aligner/readFilesIn"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/threads",
                            "id": "#allele-alignreads-se-pe.cwl/reference_star_aligner/threads"
                        }
                    ],
                    "out": [
                        "#allele-alignreads-se-pe.cwl/reference_star_aligner/aligned_file",
                        "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_final",
                        "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_out",
                        "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_progress",
                        "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_std",
                        "#allele-alignreads-se-pe.cwl/reference_star_aligner/uniquely_mapped_reads_number"
                    ],
                    "id": "#allele-alignreads-se-pe.cwl/reference_star_aligner"
                },
                {
                    "run": "#allele-process-strain.cwl",
                    "in": [
                        {
                            "source": "#allele-alignreads-se-pe.cwl/chrom_length_file",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/chrom_length_file"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/strain1",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/current_strain_name"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/hal_file",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/hal_file"
                        },
                        {
                            "source": [
                                "#allele-alignreads-se-pe.cwl/fastq_files",
                                "#allele-alignreads-se-pe.cwl/insilico_star_aligner/uniquely_mapped_reads_number"
                            ],
                            "valueFrom": "${ return (Array.isArray(self[0]) && self[0].length>1)?2*self[1]:self[1]; }",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/mapped_reads_number"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/fastq_files",
                            "valueFrom": "$(default_output_name(self))",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/output_file_prefix"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/ref_strain",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/reference_strain_name"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/aligned_file",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/sam_file"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/threads",
                            "id": "#allele-alignreads-se-pe.cwl/strain1_process/threads"
                        }
                    ],
                    "out": [
                        "#allele-alignreads-se-pe.cwl/strain1_process/bambai_pair",
                        "#allele-alignreads-se-pe.cwl/strain1_process/bigwig_file"
                    ],
                    "id": "#allele-alignreads-se-pe.cwl/strain1_process"
                },
                {
                    "run": "#allele-process-strain.cwl",
                    "in": [
                        {
                            "source": "#allele-alignreads-se-pe.cwl/chrom_length_file",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/chrom_length_file"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/strain2",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/current_strain_name"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/hal_file",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/hal_file"
                        },
                        {
                            "source": [
                                "#allele-alignreads-se-pe.cwl/fastq_files",
                                "#allele-alignreads-se-pe.cwl/insilico_star_aligner/uniquely_mapped_reads_number"
                            ],
                            "valueFrom": "${ return (Array.isArray(self[0]) && self[0].length>1)?2*self[1]:self[1]; }",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/mapped_reads_number"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/fastq_files",
                            "valueFrom": "$(default_output_name(self))",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/output_file_prefix"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/ref_strain",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/reference_strain_name"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/aligned_file",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/sam_file"
                        },
                        {
                            "source": "#allele-alignreads-se-pe.cwl/threads",
                            "id": "#allele-alignreads-se-pe.cwl/strain2_process/threads"
                        }
                    ],
                    "out": [
                        "#allele-alignreads-se-pe.cwl/strain2_process/bambai_pair",
                        "#allele-alignreads-se-pe.cwl/strain2_process/bigwig_file"
                    ],
                    "id": "#allele-alignreads-se-pe.cwl/strain2_process"
                }
            ],
            "doc": "Workflow maps FASTQ files from `fastq_files` input into reference genome `reference_star_indices_folder` and\ninsilico generated `insilico_star_indices_folder` genome (concatenated genome for both `strain1` and `strain2` strains).\nFor both genomes STAR is run with `outFilterMultimapNmax` parameter set to 1 to discard all of the multimapped reads.\nFor insilico genome SAM file is generated. Then it's splitted into two SAM files based on strain names and then sorted\nby coordinates into the BAM format. For reference genome output BAM file from STAR slignment is also coordinate sorted.\n",
            "id": "#allele-alignreads-se-pe.cwl",
            "http://schema.org/name": "allele-alignreads-se-pe",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/allele-alignreads-se-pe.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Workflow corresponds to MEA alignReads command from\nhttps://github.com/julienrichardalbert/MEA/blob/e3de228734bafd957cc2072dd8a6a0e84d554724/src/scripts/alignReads.sh\nSamtools quality and flag filtering of generated SAM/BAM files are replaced by outFilterMultimapNmax=1 parameter on\nmapping stage. Flag filtering 1540 should be clarified as long as it's not absolutely the same as STAR's implementation\nof outFilterMultimapNmax=1.",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_final",
                    "label": "STAR final log for insilico genome",
                    "doc": "STAR Log.final.out for insilico genome",
                    "id": "#allele-alignreads-se-pe.cwl/insilico_star_final_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_out",
                    "label": "STAR log out for insilico genome",
                    "doc": "STAR Log.out for insilico genome",
                    "id": "#allele-alignreads-se-pe.cwl/insilico_star_out_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_progress",
                    "label": "STAR progress log for insilico genome",
                    "doc": "STAR Log.progress.out for insilico genome",
                    "id": "#allele-alignreads-se-pe.cwl/insilico_star_progress_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#allele-alignreads-se-pe.cwl/insilico_star_aligner/log_std",
                    "label": "STAR stdout log for insilico genome",
                    "doc": "STAR Log.std.out for insilico genome",
                    "id": "#allele-alignreads-se-pe.cwl/insilico_star_stdout_log"
                },
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/reference_process/bambai_pair",
                    "label": "Reference output BAM",
                    "doc": "Coordinate sorted BAM file mapped to reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/reference_bambai_pair"
                },
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/reference_process/bigwig_file",
                    "label": "Reference bigWig file",
                    "doc": "Generated BigWig file for the reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/reference_bigwig"
                },
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_final",
                    "label": "STAR final log for reference genome",
                    "doc": "STAR Log.final.out for reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/reference_star_final_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_out",
                    "label": "STAR log out for reference genome",
                    "doc": "STAR Log.out for reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/reference_star_out_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_progress",
                    "label": "STAR progress log for reference genome",
                    "doc": "STAR Log.progress.out for reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/reference_star_progress_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#allele-alignreads-se-pe.cwl/reference_star_aligner/log_std",
                    "label": "STAR stdout log for reference genome",
                    "doc": "STAR Log.std.out for reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/reference_star_stdout_log"
                },
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/strain1_process/bambai_pair",
                    "label": "I strain output BAM",
                    "doc": "Coordinate sorted BAM file mapped to the first strain genome, not projected to reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/strain1_bambai_pair"
                },
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/strain1_process/bigwig_file",
                    "label": "I strain bigWig file",
                    "doc": "Generated bigWig file for the first strain, projected to reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/strain1_bigwig"
                },
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/strain2_process/bambai_pair",
                    "label": "II strain output BAM",
                    "doc": "Coordinate sorted BAM file mapped to the second strain genome, not projected to reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/strain2_bambai_pair"
                },
                {
                    "type": "File",
                    "outputSource": "#allele-alignreads-se-pe.cwl/strain2_process/bigwig_file",
                    "label": "II strain bigWig file",
                    "doc": "Generated bigWig file for the second strain, projected to reference genome",
                    "id": "#allele-alignreads-se-pe.cwl/strain2_bigwig"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "BAM file",
                    "doc": "BAM file mapped to reference genome",
                    "id": "#allele-process-reference.cwl/bam_file"
                },
                {
                    "type": "File",
                    "label": "Chromosome length file for reference genome",
                    "doc": "Chromosome length file for reference genome",
                    "id": "#allele-process-reference.cwl/chrom_length_file"
                },
                {
                    "type": "int",
                    "label": "Uniquely mapped reads number",
                    "doc": "Uniquely mapped to reference genome reads number",
                    "id": "#allele-process-reference.cwl/mapped_reads_number"
                },
                {
                    "type": "string",
                    "label": "Prefix for all generated output files",
                    "doc": "Corresponds to UID",
                    "id": "#allele-process-reference.cwl/output_file_prefix"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "id": "#allele-process-reference.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#allele-process-reference.cwl/samtools_sort_index/bam_bai_pair",
                    "label": "Reference BAM",
                    "doc": "Coordinate sorted BAM file mapped to reference genome",
                    "id": "#allele-process-reference.cwl/bambai_pair"
                },
                {
                    "type": "File",
                    "label": "Reference bigWig file",
                    "doc": "Generated bigWig file for reference genome",
                    "outputSource": "#allele-process-reference.cwl/bam_to_bigwig/bigwig_file",
                    "id": "#allele-process-reference.cwl/bigwig_file"
                }
            ],
            "steps": [
                {
                    "run": "#bam-bedgraph-bigwig.cwl",
                    "in": [
                        {
                            "source": "#allele-process-reference.cwl/samtools_sort_index/bam_bai_pair",
                            "id": "#allele-process-reference.cwl/bam_to_bigwig/bam_file"
                        },
                        {
                            "source": "#allele-process-reference.cwl/chrom_length_file",
                            "id": "#allele-process-reference.cwl/bam_to_bigwig/chrom_length_file"
                        },
                        {
                            "source": "#allele-process-reference.cwl/mapped_reads_number",
                            "id": "#allele-process-reference.cwl/bam_to_bigwig/mapped_reads_number"
                        }
                    ],
                    "out": [
                        "#allele-process-reference.cwl/bam_to_bigwig/bigwig_file"
                    ],
                    "id": "#allele-process-reference.cwl/bam_to_bigwig"
                },
                {
                    "run": "#samtools-sort-index.cwl",
                    "in": [
                        {
                            "source": "#allele-process-reference.cwl/bam_file",
                            "id": "#allele-process-reference.cwl/samtools_sort_index/sort_input"
                        },
                        {
                            "source": "#allele-process-reference.cwl/output_file_prefix",
                            "valueFrom": "$(self+\".bam\")",
                            "id": "#allele-process-reference.cwl/samtools_sort_index/sort_output_filename"
                        },
                        {
                            "source": "#allele-process-reference.cwl/threads",
                            "id": "#allele-process-reference.cwl/samtools_sort_index/threads"
                        }
                    ],
                    "out": [
                        "#allele-process-reference.cwl/samtools_sort_index/bam_bai_pair"
                    ],
                    "id": "#allele-process-reference.cwl/samtools_sort_index"
                }
            ],
            "id": "#allele-process-reference.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Chromosome length file for reference genome",
                    "doc": "Chromosome length file for reference genome",
                    "id": "#allele-process-strain.cwl/chrom_length_file"
                },
                {
                    "type": "string",
                    "label": "Current strain name",
                    "doc": "Current strain name",
                    "id": "#allele-process-strain.cwl/current_strain_name"
                },
                {
                    "type": "File",
                    "label": "HAL file",
                    "doc": "HAL file that includes current and reference strain information",
                    "id": "#allele-process-strain.cwl/hal_file"
                },
                {
                    "type": "int",
                    "label": "Mapped to concatenated genome reads number",
                    "doc": "Mapped to concatenated genome reads number to calculate scaling factor",
                    "id": "#allele-process-strain.cwl/mapped_reads_number"
                },
                {
                    "type": "string",
                    "label": "Prefix for all generated output files",
                    "doc": "Corresponds to UID",
                    "id": "#allele-process-strain.cwl/output_file_prefix"
                },
                {
                    "type": "string",
                    "label": "Reference strain name",
                    "doc": "Reference strain name to be projected to",
                    "id": "#allele-process-strain.cwl/reference_strain_name"
                },
                {
                    "type": "File",
                    "label": "SAM file",
                    "doc": "SAM file with reads from both strains mapped to concatenated genome",
                    "id": "#allele-process-strain.cwl/sam_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "id": "#allele-process-strain.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#allele-process-strain.cwl/samtools_sort_index/bam_bai_pair",
                    "label": "BAM mapped to strain genome, not projected to reference genome",
                    "doc": "Coordinate sorted BAM file mapped to the current strain genome, not projected to reference genome",
                    "id": "#allele-process-strain.cwl/bambai_pair"
                },
                {
                    "type": "File",
                    "label": "Strain specific bigWig file",
                    "doc": "Generated bigWig file for the current strain, projected to reference genome",
                    "outputSource": "#allele-process-strain.cwl/bedgraph_to_bigwig/bigwig_file",
                    "id": "#allele-process-strain.cwl/bigwig_file"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-genomecov.cwl",
                    "in": [
                        {
                            "default": "-bg",
                            "id": "#allele-process-strain.cwl/bam_to_bedgraph/depth"
                        },
                        {
                            "source": "#allele-process-strain.cwl/samtools_sort_index/bam_bai_pair",
                            "id": "#allele-process-strain.cwl/bam_to_bedgraph/input_file"
                        },
                        {
                            "source": "#allele-process-strain.cwl/mapped_reads_number",
                            "id": "#allele-process-strain.cwl/bam_to_bedgraph/mapped_reads_number"
                        },
                        {
                            "default": true,
                            "id": "#allele-process-strain.cwl/bam_to_bedgraph/split"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/bam_to_bedgraph/genome_coverage_file"
                    ],
                    "id": "#allele-process-strain.cwl/bam_to_bedgraph"
                },
                {
                    "run": "#ucsc-bedgraphtobigwig.cwl",
                    "in": [
                        {
                            "source": "#allele-process-strain.cwl/remove_overlaps/output_file",
                            "id": "#allele-process-strain.cwl/bedgraph_to_bigwig/bedgraph_file"
                        },
                        {
                            "source": "#allele-process-strain.cwl/chrom_length_file",
                            "id": "#allele-process-strain.cwl/bedgraph_to_bigwig/chrom_length_file"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/bedgraph_to_bigwig/bigwig_file"
                    ],
                    "id": "#allele-process-strain.cwl/bedgraph_to_bigwig"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#allele-process-strain.cwl/project_bedgraph/projected_bed_file",
                            "id": "#allele-process-strain.cwl/filter_projected_bedgraph/input_file"
                        },
                        {
                            "default": "chr",
                            "id": "#allele-process-strain.cwl/filter_projected_bedgraph/param"
                        },
                        {
                            "default": "cat \"$0\" | grep \"$1\" > `basename $0`",
                            "id": "#allele-process-strain.cwl/filter_projected_bedgraph/script"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/filter_projected_bedgraph/output_file"
                    ],
                    "id": "#allele-process-strain.cwl/filter_projected_bedgraph"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#allele-process-strain.cwl/sam_file",
                            "id": "#allele-process-strain.cwl/filter_sam/input_file"
                        },
                        {
                            "source": "#allele-process-strain.cwl/current_strain_name",
                            "valueFrom": "$(self+\"_\")",
                            "id": "#allele-process-strain.cwl/filter_sam/param"
                        },
                        {
                            "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1/chr/g\"  > `basename $0`",
                            "id": "#allele-process-strain.cwl/filter_sam/script"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/filter_sam/output_file"
                    ],
                    "id": "#allele-process-strain.cwl/filter_sam"
                },
                {
                    "run": "#halliftover.cwl",
                    "in": [
                        {
                            "source": "#allele-process-strain.cwl/hal_file",
                            "id": "#allele-process-strain.cwl/project_bedgraph/hal_file"
                        },
                        {
                            "source": "#allele-process-strain.cwl/sort_bedgraph/sorted_file",
                            "id": "#allele-process-strain.cwl/project_bedgraph/input_bed_file"
                        },
                        {
                            "source": "#allele-process-strain.cwl/current_strain_name",
                            "id": "#allele-process-strain.cwl/project_bedgraph/source_genome_name"
                        },
                        {
                            "source": "#allele-process-strain.cwl/reference_strain_name",
                            "id": "#allele-process-strain.cwl/project_bedgraph/target_genome_name"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/project_bedgraph/projected_bed_file"
                    ],
                    "id": "#allele-process-strain.cwl/project_bedgraph"
                },
                {
                    "run": "#custom-bedops.cwl",
                    "in": [
                        {
                            "source": "#allele-process-strain.cwl/sort_filtered_bedgraph/output_file",
                            "id": "#allele-process-strain.cwl/remove_overlaps/input_file"
                        },
                        {
                            "default": "bedops --partition \"$0\" | bedmap --echo --echo-map-id --delim \"\\t\" - \"$0\" | awk '{n=split($4,reads,\";\"); sum=0; for(i=1;i<=n;i++) sum+=reads[i]; $4=sum; print $0 }' > `basename $0`",
                            "id": "#allele-process-strain.cwl/remove_overlaps/script"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/remove_overlaps/output_file"
                    ],
                    "id": "#allele-process-strain.cwl/remove_overlaps"
                },
                {
                    "run": "#samtools-sort-index.cwl",
                    "in": [
                        {
                            "source": "#allele-process-strain.cwl/filter_sam/output_file",
                            "id": "#allele-process-strain.cwl/samtools_sort_index/sort_input"
                        },
                        {
                            "source": [
                                "#allele-process-strain.cwl/output_file_prefix",
                                "#allele-process-strain.cwl/current_strain_name"
                            ],
                            "valueFrom": "$(self.join(\"_\")+\".bam\")",
                            "id": "#allele-process-strain.cwl/samtools_sort_index/sort_output_filename"
                        },
                        {
                            "source": "#allele-process-strain.cwl/threads",
                            "id": "#allele-process-strain.cwl/samtools_sort_index/threads"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/samtools_sort_index/bam_bai_pair"
                    ],
                    "id": "#allele-process-strain.cwl/samtools_sort_index"
                },
                {
                    "run": "#linux-sort.cwl",
                    "in": [
                        {
                            "default": [
                                "1,1",
                                "2,2n"
                            ],
                            "id": "#allele-process-strain.cwl/sort_bedgraph/key"
                        },
                        {
                            "source": "#allele-process-strain.cwl/bam_to_bedgraph/genome_coverage_file",
                            "id": "#allele-process-strain.cwl/sort_bedgraph/unsorted_file"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/sort_bedgraph/sorted_file"
                    ],
                    "id": "#allele-process-strain.cwl/sort_bedgraph"
                },
                {
                    "run": "#custom-bedops.cwl",
                    "in": [
                        {
                            "source": "#allele-process-strain.cwl/filter_projected_bedgraph/output_file",
                            "id": "#allele-process-strain.cwl/sort_filtered_bedgraph/input_file"
                        },
                        {
                            "default": "sort-bed \"$0\" > `basename $0`",
                            "id": "#allele-process-strain.cwl/sort_filtered_bedgraph/script"
                        }
                    ],
                    "out": [
                        "#allele-process-strain.cwl/sort_filtered_bedgraph/output_file"
                    ],
                    "id": "#allele-process-strain.cwl/sort_filtered_bedgraph"
                }
            ],
            "id": "#allele-process-strain.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Input BAM file",
                    "doc": "Input BAM file, sorted by coordinates",
                    "id": "#bam-bedgraph-bigwig.cwl/bam_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "bedGraph output filename",
                    "doc": "Output filename for generated bedGraph",
                    "id": "#bam-bedgraph-bigwig.cwl/bedgraph_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "bigWig output filename",
                    "doc": "Output filename for generated bigWig",
                    "id": "#bam-bedgraph-bigwig.cwl/bigwig_filename"
                },
                {
                    "type": "File",
                    "label": "Chromosome length file",
                    "doc": "Tab delimited chromosome length file: <chromName><TAB><chromSize>",
                    "id": "#bam-bedgraph-bigwig.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Enable dUTP",
                    "doc": "Change strand af the mate read, so both reads come from the same strand",
                    "id": "#bam-bedgraph-bigwig.cwl/dutp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Fixed fragment size",
                    "doc": "Set fixed fragment size for genome coverage calculation",
                    "id": "#bam-bedgraph-bigwig.cwl/fragment_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Mapped reads number",
                    "doc": "Parameter to calculate scale as 1000000/mapped_reads_number. Ignored by bedtools-genomecov.cwl in\nbam_to_bedgraph step if scale is provided\n",
                    "id": "#bam-bedgraph-bigwig.cwl/mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Enable paired-end genome coverage calculation",
                    "doc": "Enable paired-end genome coverage calculation",
                    "id": "#bam-bedgraph-bigwig.cwl/pairchip"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "label": "Genome coverage scaling coefficient",
                    "doc": "Coefficient to scale the genome coverage by a constant factor",
                    "id": "#bam-bedgraph-bigwig.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Split reads by 'N' and 'D'",
                    "doc": "Calculate genome coverage for each part of the splitted by 'N' and 'D' read",
                    "id": "#bam-bedgraph-bigwig.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "Enable strand specific genome coverage calculation",
                    "doc": "Calculate genome coverage of intervals from a specific strand",
                    "id": "#bam-bedgraph-bigwig.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file",
                    "label": "bedGraph output file",
                    "doc": "bedGraph output file",
                    "id": "#bam-bedgraph-bigwig.cwl/bedgraph_file"
                },
                {
                    "type": "File",
                    "outputSource": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bigwig_file",
                    "label": "bigWig output file",
                    "doc": "bigWig output file",
                    "id": "#bam-bedgraph-bigwig.cwl/bigwig_file"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-genomecov.cwl",
                    "in": [
                        {
                            "default": "-bg",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/depth"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/dutp",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/du"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/fragment_size",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/fragment_size"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bam_file",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/input_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/mapped_reads_number",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/mapped_reads_number"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bedgraph_filename",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/output_filename"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/pairchip",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/pairchip"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/scale",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/scale"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/split",
                            "valueFrom": "${\n  if (self == null){\n    return true;\n  } else {\n    return self;\n  }\n}\n",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/split"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/strand",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/strand"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/genome_coverage_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph"
                },
                {
                    "run": "#linux-sort.cwl",
                    "in": [
                        {
                            "default": [
                                "1,1",
                                "2,2n"
                            ],
                            "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/key"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/genome_coverage_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/unsorted_file"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph"
                },
                {
                    "run": "#ucsc-bedgraphtobigwig.cwl",
                    "in": [
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bedgraph_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/chrom_length_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/chrom_length_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bigwig_filename",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/output_filename"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bigwig_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig"
                }
            ],
            "doc": "Workflow converts input BAM file into bigWig and bedGraph files\n",
            "id": "#bam-bedgraph-bigwig.cwl",
            "http://schema.org/name": "bam-bedgraph-bigwig",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/bam-bedgraph-bigwig.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Workflow converts input BAM file into bigWig and bedGraph files.\n\nInput BAM file should be sorted by coordinates (required by `bam_to_bedgraph` step).\n\nIf `split` input is not provided use true by default. Default logic is implemented in `valueFrom` field of `split`\ninput inside `bam_to_bedgraph` step to avoid possible bug in cwltool with setting default values for workflow inputs.\n\n`scale` has higher priority over the `mapped_reads_number`. The last one is used to calculate `-scale` parameter for\n`bedtools genomecov` (step `bam_to_bedgraph`) only in a case when input `scale` is not provided. All logic is\nimplemented inside `bedtools-genomecov.cwl`.\n\n`bigwig_filename` defines the output name only for generated bigWig file. `bedgraph_filename` defines the output name\nfor generated bedGraph file and can influence on generated bigWig filename in case when `bigwig_filename` is not provided.\n\nAll workflow inputs and outputs don't have `format` field to avoid format incompatibility errors when workflow is used\nas subworkflow."
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { let ext = (inputs.depth == \"-bg\" || inputs.depth == \"-bga\")?\".bedGraph\":\".tab\"; return inputs.input_file.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.') + ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bedtools2:v2.26.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 17,
                        "prefix": "-g"
                    },
                    "doc": "Input genome file. Needed only when -i flag. The genome file is tab delimited <chromName><TAB><chromSize>\n",
                    "id": "#bedtools-genomecov.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#bedtools-genomecov.cwl/depth/depth",
                            "symbols": [
                                "#bedtools-genomecov.cwl/depth/depth/-bg",
                                "#bedtools-genomecov.cwl/depth/depth/-bga",
                                "#bedtools-genomecov.cwl/depth/depth/-d",
                                "#bedtools-genomecov.cwl/depth/depth/-dz"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Report the depth type. By default, bedtools genomecov will compute a histogram of coverage\nfor the genome file provided (intputs.chrom_length_file)\n",
                    "id": "#bedtools-genomecov.cwl/depth"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-du"
                    },
                    "doc": "Change strand af the mate read (so both reads from the same strand) useful for strand specific.\nWorks for BAM files only\n",
                    "id": "#bedtools-genomecov.cwl/du"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-fs"
                    },
                    "doc": "Set fixed fragment size\n",
                    "id": "#bedtools-genomecov.cwl/fragment_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 16,
                        "valueFrom": "${\n  var prefix = ((/.*\\.bam$/i).test(inputs.input_file.path))?'-ibam':'-i';\n  return [prefix, inputs.input_file.path];\n}\n"
                    },
                    "doc": "The input file can be in BAM format (Note: BAM must be sorted by position) or <bed/gff/vcf>.\nPrefix is selected on the base of input file extension\n",
                    "id": "#bedtools-genomecov.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "-3"
                    },
                    "doc": "Calculate coverage of 3\" positions (instead of entire interval)\n",
                    "id": "#bedtools-genomecov.cwl/m3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "-5"
                    },
                    "doc": "Calculate coverage of 5\" positions (instead of entire interval)\n",
                    "id": "#bedtools-genomecov.cwl/m5"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-scale",
                        "valueFrom": "${\n  if (inputs.scale){\n    return null;\n  } else if (inputs.mapped_reads_number) {\n    return 1000000/inputs.mapped_reads_number;\n  } else {\n    return null;\n  }\n}\n"
                    },
                    "doc": "Optional parameter to calculate scale as 1000000/mapped_reads_number if inputs.scale is not provided\n",
                    "id": "#bedtools-genomecov.cwl/mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-max"
                    },
                    "doc": "Combine all positions with a depth >= max into\na single bin in the histogram. Irrelevant\nfor -d and -bedGraph\n- (INTEGER)\n",
                    "id": "#bedtools-genomecov.cwl/max"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#bedtools-genomecov.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-pc"
                    },
                    "doc": "pair-end chip seq experiment\n",
                    "id": "#bedtools-genomecov.cwl/pairchip"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-scale"
                    },
                    "doc": "Scale the coverage by a constant factor.\nEach coverage value is multiplied by this factor before being reported.\nUseful for normalizing coverage by, e.g., reads per million (RPM).\n- Default is 1.0; i.e., unscaled.\n- (FLOAT)\n",
                    "id": "#bedtools-genomecov.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-split"
                    },
                    "doc": "treat \"split\" BAM or BED12 entries as distinct BED intervals.\nwhen computing coverage.\nFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\nto infer the blocks for computing coverage.\nFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\nfields (i.e., columns 10,11,12).\n",
                    "id": "#bedtools-genomecov.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-strand"
                    },
                    "doc": "Calculate coverage of intervals from a specific strand.\nWith BED files, requires at least 6 columns (strand is column 6).\n- (STRING): can be + or -\n",
                    "id": "#bedtools-genomecov.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "Generated genome coverage output file\n",
                    "id": "#bedtools-genomecov.cwl/genome_coverage_file",
                    "outputBinding": {
                        "glob": "${\n    return inputs.output_filename ? inputs.output_filename : default_output_filename();\n }\n"
                    }
                }
            ],
            "stdout": "${\n    return inputs.output_filename ? inputs.output_filename : default_output_filename();\n }\n",
            "baseCommand": [
                "bedtools",
                "genomecov"
            ],
            "doc": "Tool calculates genome coverage from input bam/bed/gff/vcf using `bedtools genomecov`\n\nDepending on `input_file` extension additional prefix is used: if `*.bam` use `-ibam`, else use `-i`.\n\n`scale` and `mapped_reads_number` inputs result in the same parameter `-scale`. If `scale` is not provided, check if\n`mapped_reads_number` is not null and calculate `-scale` as `1000000/mapped_reads_number`. If both inputs are\nnull, `bedtools genomecov` will use its default scaling value.\n\n`default_output_filename` function returns default output filename and is used when `output_filename` is not provided.\nDefault output file extention is `.tab`. If bedGraph should be generated (check flags `inputs.depth`), extension is\nupdated to `.bedGraph`. Default basename of the output file is generated on the base of `input_file` basename.\n",
            "id": "#bedtools-genomecov.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#bedtools-metadata.yaml",
                "http://schema.org/name": "bowtie2",
                "http://schema.org/about": "A software suite for the comparison, manipulation and annotation of genomic features in browser extensible data (BED) and general feature format (GFF) format. BEDTools also supports the comparison of sequence alignments in BAM format to both BED and GFF features. The tools are extremely efficient and allow the user to compare large datasets (e.g. next-generation sequencing data) with both public and custom genome annotation tracks. BEDTools can be combined with one another as well as with standard UNIX commands, thus facilitating routine genomics tasks as well as pipelines that can quickly answer intricate questions of large genomic datasets.\n",
                "http://schema.org/url": "http://bedtools.readthedocs.org",
                "http://schema.org/codeRepository": "https://github.com/arq5x/bedtools2",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "2.26.0",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#bedtools-metadata.yaml/10.1093/bioinformatics/btq033",
                        "datePublished": "28 January 2010",
                        "http://schema.org/name": "BEDTools: a flexible suite of utilities for comparing genomic features",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron R. Quinlan"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ira M. Hall"
                            }
                        ],
                        "http://schema.org/url": "https://academic.oup.com/bioinformatics/article-lookup/doi/10.1093/bioinformatics/btq033"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/arq5x/bedtools2/issues",
                    "https://groups.google.com/forum/#!forum/bedtools-discuss"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "University of Utah",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron Quinlan",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Neil Kindlon",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "bedtools-genomecov",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/bedtools-genomecov.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: bedtools genomecov [OPTIONS] -i <bed/gff/vcf> -g <genome>\n\nOptions:\n\t-ibam\t\tThe input file is in BAM format.\n\t\t\tNote: BAM _must_ be sorted by position\n\n\t-d\t\tReport the depth at each genome position (with one-based coordinates).\n\t\t\tDefault behavior is to report a histogram.\n\n\t-dz\t\tReport the depth at each genome position (with zero-based coordinates).\n\t\t\tReports only non-zero positions.\n\t\t\tDefault behavior is to report a histogram.\n\n\t-bg\t\tReport depth in BedGraph format. For details, see:\n\t\t\tgenome.ucsc.edu/goldenPath/help/bedgraph.html\n\n\t-bga\t\tReport depth in BedGraph format, as above (-bg).\n\t\t\tHowever with this option, regions with zero\n\t\t\tcoverage are also reported. This allows one to\n\t\t\tquickly extract all regions of a genome with 0\n\t\t\tcoverage by applying: \"grep -w 0$\" to the output.\n\n\t-split\t\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\t\t\twhen computing coverage.\n\t\t\tFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\n\t\t\tto infer the blocks for computing coverage.\n\t\t\tFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\n\t\t\tfields (i.e., columns 10,11,12).\n\n\t-strand\t\tCalculate coverage of intervals from a specific strand.\n\t\t\tWith BED files, requires at least 6 columns (strand is column 6).\n\t\t\t- (STRING): can be + or -\n\n\t-pc\t\tCalculate coverage of pair-end fragments.\n\t\t\tWorks for BAM files only\n\t-fs\t\tForce to use provided fragment size instead of read length\n\t\t\tWorks for BAM files only\n\t-du\t\tChange strand af the mate read (so both reads from the same strand) useful for strand specific\n\t\t\tWorks for BAM files only\n\t-5\t\tCalculate coverage of 5\" positions (instead of entire interval).\n\n\t-3\t\tCalculate coverage of 3\" positions (instead of entire interval).\n\n\t-max\t\tCombine all positions with a depth >= max into\n\t\t\ta single bin in the histogram. Irrelevant\n\t\t\tfor -d and -bedGraph\n\t\t\t- (INTEGER)\n\n\t-scale\t\tScale the coverage by a constant factor.\n\t\t\tEach coverage value is multiplied by this factor before being reported.\n\t\t\tUseful for normalizing coverage by, e.g., reads per million (RPM).\n\t\t\t- Default is 1.0; i.e., unscaled.\n\t\t\t- (FLOAT)\n\n\t-trackline\tAdds a UCSC/Genome-Browser track line definition in the first line of the output.\n\t\t\t- See here for more details about track line definition:\n\t\t\t      http://genome.ucsc.edu/goldenPath/help/bedgraph.html\n\t\t\t- NOTE: When adding a trackline definition, the output BedGraph can be easily\n\t\t\t      uploaded to the Genome Browser as a custom track,\n\t\t\t      BUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n\n\t-trackopts\tWrites additional track line definition parameters in the first line.\n\t\t\t- Example:\n\t\t\t   -trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\n\t\t\t   Note the use of single-quotes if you have spaces in your parameters.\n\t\t\t- (TEXT)\n\nNotes:\n\t(1) The genome file should tab delimited and structured as follows:\n\t <chromName><TAB><chromSize>\n\n\tFor example, Human (hg19):\n\tchr1\t249250621\n\tchr2\t243199373\n\t...\n\tchr18_gl000207_random\t4262\n\n\t(2) The input BED (-i) file must be grouped by chromosome.\n\t A simple \"sort -k 1,1 <BED> > <BED>.sorted\" will suffice.\n\n\t(3) The input BAM (-ibam) file must be sorted by position.\n\t A \"samtools sort <BAM>\" should suffice.\n\nTips:\n\tOne can use the UCSC Genome Browser's MySQL database to extract\n\tchromosome sizes. For example, H. sapiens:\n\n\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\\n\t\"select chrom, size from hg19.chromInfo\" > hg19.genome\n"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bedops:v2.4.34"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bedops.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bedops.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bedops.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename)"
                    },
                    "id": "#custom-bedops.cwl/output_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`. Based on bedops Dockerfile\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n\nThe temporary solution before the bedmap.cwl will be created\n",
            "id": "#custom-bedops.cwl",
            "http://schema.org/name": "custom-bedops",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bedops.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Compressed or uncompressed FASTQ file\n",
                    "id": "#extract-fastq.cwl/compressed_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7
                    },
                    "default": ".fastq",
                    "doc": "Default extension for the extracted file\n",
                    "id": "#extract-fastq.cwl/output_file_ext"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nshopt -s nocaseglob\n\nFILE=$0\nDEFAULT_EXT=$1\n\nEXT_LIST=( \".fastq\" \".fq\" )\n\nBASENAME=$(basename \"$FILE\")\nROOT_NAME=\"${BASENAME%.*}\"\n\nfor ITEM in $EXT_LIST; do\n  if [[ $ROOT_NAME == *$ITEM ]]; then\n    DEFAULT_EXT=\"\"\n  fi\ndone\n\nT=`file -b \"${FILE}\" | awk '{print $1}'`\ncase \"${T}\" in\n  \"bzip2\"|\"gzip\"|\"Zip\")\n    7z e -so \"${FILE}\" > \"${ROOT_NAME}${DEFAULT_EXT}\"\n    ;;\n  \"ASCII\")\n    cp \"${FILE}\" \"${ROOT_NAME}${DEFAULT_EXT}\" || true\n    ;;\n  *)\n    echo \"Error: file type unknown\"\n    exit 1\nesac\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash script to extract compressed FASTQ file\n",
                    "id": "#extract-fastq.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#extract-fastq.cwl/fastq_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to decompress input FASTQ file\nBash script's logic:\n- disable case sensitive glob check\n- check if root name of input file already include '.fastq' or '.fq' extension. If yes, set DEFAULT_EXT to \"\"\n- check file type, decompress if needed\n- return 1, if file type is not recognized\nThis script also works of input file doesn't have any extension at all\n",
            "id": "#extract-fastq.cwl",
            "http://schema.org/name": "extract-fastq",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/extract-fastq.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Tool to decompress input FASTQ file"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { var ext = \".bed\"; if (inputs.output_filename == \"\"){ let root = inputs.input_bed_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_bed_file.basename+ext:root+ext; } else { return inputs.output_filename; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/hal:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "Input HAL file\n",
                    "id": "#halliftover.cwl/hal_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Input BED file\n",
                    "id": "#halliftover.cwl/input_bed_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--keepExtra"
                    },
                    "doc": "keep extra columns. these are columns in the input\nbeyond the specified or detected bed version, and which\nare cut by default\n",
                    "id": "#halliftover.cwl/keep_extra"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--noDupes"
                    },
                    "doc": "Do not map between duplications in graph\n",
                    "id": "#halliftover.cwl/no_dupes"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "valueFrom": "$(default_output_filename())"
                    },
                    "default": "",
                    "doc": "Output filename\n",
                    "id": "#halliftover.cwl/output_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Source genome name\n",
                    "id": "#halliftover.cwl/source_genome_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--tab"
                    },
                    "default": true,
                    "doc": "input is tab-separated. this allows column entries to\ncontain spaces.  if this flag is not set, both spaces\nand tabs are used to separate input columns\n",
                    "id": "#halliftover.cwl/tab_separated"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "Target genome name\n",
                    "id": "#halliftover.cwl/target_genome_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(default_output_filename())"
                    },
                    "doc": "Projected BED file\n",
                    "id": "#halliftover.cwl/projected_bed_file"
                }
            ],
            "baseCommand": [
                "halLiftover"
            ],
            "doc": "Runs halliftover to project input BED file from source to target genome.\n`source_genome_name` and `target_genome_name` should correspond to the fields in `hal_file`.\n\nIf `output_filename` is not set, call `default_output_filename` function.\n\nThe following parameters are not yet supported:\n  --outPSL\n  --outPSLWithName\n\nhalLiftover manual doesn't say anything if `input_bed_file` should be sorted or not\n",
            "id": "#halliftover.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#hal-metadata.yaml",
                "http://schema.org/name": "HAL",
                "http://schema.org/about": "HAL tools"
            },
            "http://schema.org/name": "halliftover",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/halliftover.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "\nUSAGE:\nhalLiftover [Options] <halFile> <srcGenome> <srcBed> <tgtGenome> <tgtBed>\n\nARGUMENTS:\nhalFile:     input hal file\nsrcGenome:   source genome name\nsrcBed:      path of input bed file.  set as stdin to stream from standard input\ntgtGenome:   target genome name\ntgtBed:      path of output bed file.  set as stdout to stream to standard output.\n\nOPTIONS:\n--append:                     append results to tgtBed [default = 0]\n--cacheBytes <value>:         maximum size in bytes of regular hdf5 cache [default =\n                              15728640]\n--cacheMDC <value>:           number of metadata slots in hdf5 cache [default = 113]\n--cacheRDC <value>:           number of regular slots in hdf5 cache.  should be a\n                              prime number ~= 10 * DefaultCacheRDCBytes / chunk\n                              [default = 599999]\n--cacheW0 <value>:            w0 parameter fro hdf5 cache [default = 0.75]\n--coalescenceLimit <value>:   coalescence limit genome: the genome at or above the\n                              MRCA of source and target at which we stop looking for\n                              homologies (default: MRCA) [default = ]\n--help:                       dsiplay this help page [default = 0]\n--inBedVersion <value>:       bed version of input file as integer between 3 and 9 or\n                               12 reflecting the number of columns (see bed format\n                              specification for more details). Will be autodetected\n                              by default. [default = 0]\n--inMemory:                   load all data in memory (and disable hdf5 cache)\n                              [default = 0]\n--keepExtra:                  keep extra columns. these are columns in the input\n                              beyond the specified or detected bed version, and which\n                               are cut by default. [default = 0]\n--noDupes:                    do not map between duplications in graph. [default = 0]\n--outBedVersion <value>:      bed version of output file as integer between 3 and 9\n                              or 12 reflecting the number of columns (see bed format\n                              specification for more details). Will be same as input\n                              by default. [default = 0]\n--outPSL:                     write output in PSL instead of bed format. overrides\n                              --outBedVersion when specified. [default = 0]\n--outPSLWithName:             write output as input BED name followed by PSL line\n                              instead of bed format. overrides --outBedVersion when\n                              specified. [default = 0]\n--tab:                        input is tab-separated. this allows column entries to\n                              contain spaces.  if this flag is not set, both spaces\n                              and tabs are used to separate input columns. [default = 0]\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function() { if (inputs.output_filename) { return inputs.output_filename; } return inputs.unsorted_file.location.split('/').slice(-1)[0]; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-k, --key=POS1[,POS2]\nstart a key at POS1, end it at POS2 (origin 1)\n",
                    "id": "#linux-sort.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#linux-sort.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#linux-sort.cwl/unsorted_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#linux-sort.cwl/sorted_file",
                    "outputBinding": {
                        "glob": "$(get_output_filename())"
                    }
                }
            ],
            "stdout": "$(get_output_filename())",
            "baseCommand": [
                "sort"
            ],
            "doc": "Tool sorts data from `unsorted_file` by key\n\n`default_output_filename` function returns file name identical to `unsorted_file`, if `output_filename` is not provided.\n",
            "id": "#linux-sort.cwl",
            "http://schema.org/name": "linux-sort",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/linux-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return  [\n            {\n              \"entry\": inputs.sort_input,\n              \"entryname\": inputs.sort_input.basename,\n              \"writable\": true\n            }\n          ]\n}\n"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var ext = function() { if (inputs.csi && !inputs.bai){ return '.csi'; } else { return '.bai'; } };",
                        "var default_bam = function() { if (inputs.trigger == true){ return inputs.sort_input.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\".bam\"; } else { return inputs.sort_input.location.split('/').slice(-1)[0]; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/samtools:v1.4"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate BAI-format index for BAM files [default]. If input isn't cram.\n",
                    "id": "#samtools-sort-index.cwl/bai"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nif [ \"$0\" = \"true\" ]\nthen\n  echo \"Run: samtools index \" ${@:1}\n  samtools index \"${@:1}\"\nelse\n  echo \"Skip samtools index \" ${@:1}\nfi\n",
                    "inputBinding": {
                        "position": 20
                    },
                    "doc": "Bash function to run samtools index with all input parameters or skip it if trigger is false\n",
                    "id": "#samtools-sort-index.cwl/bash_script_index"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nif [ \"$0\" = \"true\" ]\nthen\n  echo \"Run: samtools sort \" ${@:1}\n  samtools sort \"${@:1}\"\nelse\n  echo \"Skip samtools sort \" ${@:1}\nfi\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash function to run samtools sort with all input parameters or skip it if trigger is false\n",
                    "id": "#samtools-sort-index.cwl/bash_script_sort"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate CSI-format index for BAM files. If input isn't cram.\n",
                    "id": "#samtools-sort-index.cwl/csi"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 24,
                        "prefix": "-m"
                    },
                    "doc": "Set minimum interval size for CSI indices to 2^INT [14]\n",
                    "id": "#samtools-sort-index.cwl/csi_interval"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-l"
                    },
                    "doc": "SORT: desired compression level for the final output file, ranging from 0 (uncompressed)\nor 1 (fastest but minimal compression) to 9 (best compression but slowest to write),\nsimilarly to gzip(1)'s compression level setting.\nIf -l is not used, the default compression level will apply.\n",
                    "id": "#samtools-sort-index.cwl/sort_compression_level"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 16
                    },
                    "doc": "Input only in.sam|in.bam|in.cram. Optionally could be supplemented with index file in secondaryFiles\n",
                    "id": "#samtools-sort-index.cwl/sort_input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-o",
                        "valueFrom": "${\n    if (self == \"\" || inputs.trigger == false){\n      return default_bam();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Write the final sorted output to FILE. Only out.bam|out.cram.\nIf output file extension is set to SAM, tool will fail on the index step\n",
                    "id": "#samtools-sort-index.cwl/sort_output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Set number of sorting and compression threads [1] (Only for sorting)\n",
                    "id": "#samtools-sort-index.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "doc": "If true - run samtools, if false - return sort_input and optional index file in secondaryFiles, previously staged\ninto output directory.\n",
                    "id": "#samtools-sort-index.cwl/trigger"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    if (inputs.sort_output_filename == \"\" || inputs.trigger == false){\n      return default_bam();\n    } else {\n      return inputs.sort_output_filename;\n    }\n}\n"
                    },
                    "secondaryFiles": "${ if (inputs.trigger == true){ return self.basename + ext(); } else { return inputs.sort_input.secondaryFiles?inputs.sort_input.secondaryFiles:\"null\"; } }",
                    "id": "#samtools-sort-index.cwl/bam_bai_pair"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "${ return inputs.trigger ? \"true\" : \"false\" }\n",
                    "position": 6
                },
                {
                    "valueFrom": "bam",
                    "position": 13,
                    "prefix": "-O"
                },
                {
                    "valueFrom": "$(inputs.threads?inputs.threads:1)",
                    "position": 15,
                    "prefix": "-@"
                },
                {
                    "valueFrom": ";",
                    "position": 17,
                    "shellQuote": false
                },
                {
                    "valueFrom": "bash",
                    "position": 18
                },
                {
                    "valueFrom": "-c",
                    "position": 19
                },
                {
                    "valueFrom": "${ return inputs.trigger ? \"true\" : \"false\" }\n",
                    "position": 21
                },
                {
                    "valueFrom": "$(inputs.bai?'-b':inputs.csi?'-c':[])",
                    "position": 23
                },
                {
                    "valueFrom": "$(inputs.threads?inputs.threads:1)",
                    "position": 25,
                    "prefix": "-@"
                },
                {
                    "valueFrom": "${\n    if (inputs.sort_output_filename == \"\" || inputs.trigger == false){\n      return default_bam();\n    } else {\n      return inputs.sort_output_filename;\n    }\n}\n",
                    "position": 26
                },
                {
                    "valueFrom": "${\n    if (inputs.sort_output_filename == \"\" || inputs.trigger == false){\n      return default_bam() + ext();\n    } else {\n      return inputs.sort_output_filename + ext();\n    }\n}\n",
                    "position": 27
                }
            ],
            "doc": "Tool to sort and index input BAM/SAM/CRAM.\nIf input `trigger` is set to `true` or isn't set at all (`true` is used by default), run `samtools sort` and\n`samtools index`, return sorted BAM and BAI/CSI index file.\nIf input `trigger` is set to `false`, return unchanged `sort_input` (BAM/SAM/CRAM) and index (BAI/CSI, if provided in\n`secondaryFiles`) files, previously staged into output directory.\n\nBefore execution `baseCommand`, `sort_input` and `secondaryFiles` (if provided) are staged into directory\nset as docker parameter `--workdir` (tool's output directory), using `InitialWorkDirRequirement`. Setting\n`writable: true` makes cwl-runner to make copies of the `sort_input` and `secondaryFiles` (if provided) and mount\nthem to docker container with `rw` mode as part of `--workdir` (if set to false, the files staged into output\ndirectory will be mounted to docker container separately with `ro` mode). Because both `samtools sort` and\n`samtools index` can overwrite files with the same names (and in case of `samtools sort` even the input file can be\noverwritten), we don't need to rename any of the staged files.\n\nTrigger logic is implemented in two bash scripts set by default as `bash_script_sort` and `bash_script_index` inputs.\nFor both of then, if the first argument $0 (which is `trigger` input) is true, run `samtools sort/index` with the rest\nof the arguments. If $0 is not true, skip `samtools sort/index` and return `sort_input` and `secondaryFiles`\n(if provided) staged into output directory.\n\nInput `trigger` is Boolean, but returns String, because of `valueFrom` field. The `valueFrom` is used, because if `trigger`\nis false, cwl-runner doesn't append this argument at all to the the `baseCommand` - new feature of CWL v1.0.2. Alternatively,\n`prefix` field could be used, but it causes changing in script logic.\n\nIf using `sort_output_filename`, the output file extension should be `*.bam`, because `samtools sort` defines the output\nfile format on the base of the file extension. If `*.sam` is sed as output filename, it cannot be usefully indexed\nby `samtools index`.\n\n`default_bam` function is used to generate output filename for `samtools sort` if input `sort_output_filename` is not\nset or when `trigger` is false and we need to return `sort_input` and `secondaryFiles` (if provided) files staged into\noutput directory. Output filename is generated on the base of `sort_input` basename with `.bam` extension by default.\n\n`ext` function is used to return the index file extension (BAI/CSI) based on `csi` and `bai` inputs according to the\nfollowing logic\n  `csi` &&  `bai`  => BAI\n !`csi` && !`bai ` => BAI\n  `csi` && !`bai ` => CSI\n",
            "id": "#samtools-sort-index.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#samtools-metadata.yaml",
                "http://schema.org/name": "samtools",
                "http://schema.org/about": "A suite of programs for interacting with high-throughput sequencing data. It consists of three separate repositories: Samtools (Reading/writing/editing/indexing/viewing SAM/BAM/CRAM format), BCFtools (Reading/writing BCF2/VCF/gVCF files and calling/filtering/summarising SNP and short indel sequence variants) and HTSlib (A C library for reading/writing high-throughput sequencing data).\n",
                "http://schema.org/url": "http://www.htslib.org/",
                "http://schema.org/codeRepository": "https://github.com/samtools/samtools.git",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT",
                    "https://opensource.org/licenses/BSD-3-Clause"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "1.4",
                    "http://schema.org/applicationCategory": "commandline tool"
                },
                "http://schema.org/programmingLanguage": "C, Perl",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btr509",
                        "http://schema.org/name": "(Li, 2011) A statistical framework for SNP calling, mutation discovery, association mapping and population genetical parameter estimation from sequencing data. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/21903627"
                    },
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btr076",
                        "http://schema.org/name": "(Li, 2011) Improving SNP discovery by base alignment quality. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/21320865"
                    },
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btp352",
                        "http://schema.org/name": "(Li et al., 2009) The Sequence Alignment/Map format and SAMtools. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/19505943"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://lists.sourceforge.net/lists/listinfo/samtools-help",
                    "https://lists.sourceforge.net/lists/listinfo/samtools-devel"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Sanger Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Heng Li",
                                "http://schema.org/description": "wrote most of the initial source codes of SAMtools and various converters."
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Broad Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bob Handsaker",
                                "http://schema.org/description": "A major contributor to the\nSAM/BAM specification. He designed and implemented the BGZF format, the\nunderlying indexable compression format for the BAM format. BGZF does\nnot support arithmetic between file offsets.\n"
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Beijing Genome Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Jue Ruan",
                                "http://schema.org/description": "Designed and implemented the\nRAZF format, an alternative indexable compression format. RAZF is no longer\nused by or provided with SAMtools. Source code remains available in older\nSAMtools 0.1.x releases and from the standalone branch in the repository.\n"
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Person",
                        "http://schema.org/name": "Colin Hercus",
                        "http://schema.org/description": "updated novo2sam.pl to support gapped alignment by novoalign."
                    },
                    {
                        "class": "http://schema.org/Person",
                        "http://schema.org/name": "Petr Danecek",
                        "http://schema.org/description": "contributed the header parsing library sam_header.c and sam2vcf.pl script."
                    }
                ]
            },
            "http://schema.org/name": "samtools-sort-index",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/samtools-sort-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: samtools sort [options...] [in.bam]\nOptions:\n  -l INT     Set compression level, from 0 (uncompressed) to 9 (best)\n  -m INT     Set maximum memory per thread; suffix K/M/G recognized [768M]\n  -n         Sort by read name\n  -o FILE    Write final output to FILE rather than standard output\n  -T PREFIX  Write temporary files to PREFIX.nnnn.bam\n      --input-fmt-option OPT[=VAL]\n               Specify a single input file format option in the form\n               of OPTION or OPTION=VALUE\n  -O, --output-fmt FORMAT[,OPT[=VAL]]...\n               Specify output format (SAM, BAM, CRAM)\n      --output-fmt-option OPT[=VAL]\n               Specify a single output file format option in the form\n               of OPTION or OPTION=VALUE\n      --reference FILE\n               Reference sequence FASTA FILE [null]\n  -@, --threads INT\n               Number of additional threads to use [0]\n\nUsage: samtools index [-bc] [-m INT] <in.bam> [out.index]\nOptions:\n  -b       Generate BAI-format index for BAM files [default]\n  -c       Generate CSI-format index for BAM files\n  -m INT   Set minimum interval size for CSI indices to 2^INT [14]\n  -@ INT   Sets the number of threads [none]\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_name_prefix = function() { if (Array.isArray(inputs.readFilesIn) && inputs.readFilesIn.length > 0){ return inputs.readFilesIn[0].location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\".\"; } else { return inputs.readFilesIn.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\".\"; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/star:v2.5.3a"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignEndsProtrude"
                    },
                    "doc": "0    ConcordantPair\nint, string:\nallow protrusion of alignment ends, i.e. start (end) of the +strand mate downstream of the start (end) of the -strand mate\n  1st word: int: maximum number of protrusion bases allowed\n  2nd word: string:\n    ConcordantPair ... report alignments with non-zero protrusion as concordant pairs\n    DiscordantPair ... report alignments with non-zero protrusion as discordant pairs\n",
                    "id": "#star-alignreads.cwl/alignEndsProtrude"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignEndsType"
                    },
                    "doc": "Local\nstring: type of read ends alignment\nLocal           ... standard local alignment with soft-clipping allowed\nEndToEnd        ... force end-to-end read alignment, do not soft-clip\nExtend5pOfRead1 ... fully extend only the 5p of the read1, all other ends: local alignment\nExtend5pOfReads12 ... fully extend only the 5p of the both read1 and read2, all other ends: local alignment\n",
                    "id": "#star-alignreads.cwl/alignEndsType"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignIntronMax"
                    },
                    "doc": "0\nmaximum intron size, if 0, max intron size will be determined by (2^winBinNbits)*winAnchorDistNbins\n",
                    "id": "#star-alignreads.cwl/alignIntronMax"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignIntronMin"
                    },
                    "doc": "21\nminimum intron size: genomic gap is considered intron if its length>=alignIntronMin,\notherwise it is considered Deletion\n",
                    "id": "#star-alignreads.cwl/alignIntronMin"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignMatesGapMax"
                    },
                    "doc": "0\nmaximum gap between two mates, if 0, max intron gap will be determined by (2^winBinNbits)*winAnchorDistNbins\n",
                    "id": "#star-alignreads.cwl/alignMatesGapMax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSJDBoverhangMin"
                    },
                    "doc": "3\nint>0: minimum overhang (i.e. block size) for annotated (sjdb) spliced alignments\n",
                    "id": "#star-alignreads.cwl/alignSJDBoverhangMin"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSJoverhangMin"
                    },
                    "doc": "5\nint>0: minimum overhang (i.e. block size) for spliced alignments\n",
                    "id": "#star-alignreads.cwl/alignSJoverhangMin"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSJstitchMismatchNmax"
                    },
                    "doc": "0 -1 0 0\n4*int>=0: maximum number of mismatches for stitching of the splice junctions (-1: no limit).\n(1) non-canonical motifs, (2) GT/AG and CT/AC motif, (3) GC/AG and CT/GC motif, (4) AT/AC and GT/AT motif.\n",
                    "id": "#star-alignreads.cwl/alignSJstitchMismatchNmax"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSoftClipAtReferenceEnds"
                    },
                    "doc": "Yes\nstring: allow the soft-clipping of the alignments past the end of the chromosomes\nYes ... allow\nNo  ... prohibit, useful for compatibility with Cufflinks\n",
                    "id": "#star-alignreads.cwl/alignSoftClipAtReferenceEnds"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSplicedMateMapLmin"
                    },
                    "doc": "0\nint>0: minimum mapped length for a read mate that is spliced\n",
                    "id": "#star-alignreads.cwl/alignSplicedMateMapLmin"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignSplicedMateMapLminOverLmate"
                    },
                    "doc": "0.66\nfloat>0: alignSplicedMateMapLmin normalized to mate length\n",
                    "id": "#star-alignreads.cwl/alignSplicedMateMapLminOverLmate"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignTranscriptsPerReadNmax"
                    },
                    "doc": "10000\nint>0: max number of different alignments per read to consider\n",
                    "id": "#star-alignreads.cwl/alignTranscriptsPerReadNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignTranscriptsPerWindowNmax"
                    },
                    "doc": "100\nint>0: max number of transcripts per window\n",
                    "id": "#star-alignreads.cwl/alignTranscriptsPerWindowNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--alignWindowsPerReadNmax"
                    },
                    "doc": "10000\nint>0: max number of windows per read\n",
                    "id": "#star-alignreads.cwl/alignWindowsPerReadNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bamRemoveDuplicatesMate2basesN"
                    },
                    "doc": "int>0: number of bases from the 5' of mate 2 to use in collapsing (e.g. for\nRAMPAGE)\n",
                    "id": "#star-alignreads.cwl/bamRemoveDuplicatesMate2basesN"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bamRemoveDuplicatesType"
                    },
                    "doc": "string: mark duplicates in the BAM file, for now only works with (i) sorted BAM feeded with inputBAMfile, and (ii) for paired-end alignments only\n-                       ... no duplicate removal/marking\nUniqueIdentical         ... mark all multimappers, and duplicate unique mappers. The coordinates, FLAG, CIGAR must be identical\nUniqueIdenticalNotMulti  ... mark duplicate unique mappers but not multimappers.\n",
                    "id": "#star-alignreads.cwl/bamRemoveDuplicatesType"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimFilter"
                    },
                    "doc": "banGenomicN\nstring(s): different filters for chimeric alignments\nNone ... no filtering\nbanGenomicN ... Ns are not allowed in the genome sequence around the chimeric junction\n",
                    "id": "#star-alignreads.cwl/chimFilter"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimJunctionOverhangMin"
                    },
                    "doc": "20\nint>=0: minimum overhang for a chimeric junction\n",
                    "id": "#star-alignreads.cwl/chimJunctionOverhangMin"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimMainSegmentMultNmax"
                    },
                    "doc": "int>=1: maximum number of multi-alignments for the main chimeric segment. =1 will prohibit multimapping main segments.\n",
                    "id": "#star-alignreads.cwl/chimMainSegmentMultNmax"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimOutType"
                    },
                    "doc": "string(s): type of chimeric output\n1st word:\nSeparateSAMold  ... output old SAM into separate Chimeric.out.sam file\nWithinBAM       ... output into main aligned BAM files (Aligned.*.bam)\n2nd word:\nWithinBAM HardClip  ... hard-clipping in the CIGAR for supplemental chimeric alignments (defaultif no 2nd word is present)\nWithinBAM SoftClip  ... soft-clipping in the CIGAR for supplemental chimeric alignments\n",
                    "id": "#star-alignreads.cwl/chimOutType"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimScoreDropMax"
                    },
                    "doc": "20\nint>=0: max drop (difference) of chimeric score (the sum of scores of all chimeric\nsegements) from the read length\n",
                    "id": "#star-alignreads.cwl/chimScoreDropMax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimScoreJunctionNonGTAG"
                    },
                    "doc": "-1\nint: penalty for a non-GT/AG chimeric junction\n",
                    "id": "#star-alignreads.cwl/chimScoreJunctionNonGTAG"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimScoreMin"
                    },
                    "doc": "0\nint>=0: minimum total (summed) score of the chimeric segments\n",
                    "id": "#star-alignreads.cwl/chimScoreMin"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimScoreSeparation"
                    },
                    "doc": "int>=0: minimum difference (separation) between the best chimeric score and\nthe next one\n",
                    "id": "#star-alignreads.cwl/chimScoreSeparation"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimSegmentMin"
                    },
                    "doc": "0\nint>=0: minimum length of chimeric segment length, if ==0, no chimeric output\n",
                    "id": "#star-alignreads.cwl/chimSegmentMin"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chimSegmentReadGapMax"
                    },
                    "doc": "0\nint>=0: maximum gap in the read sequence between chimeric segments\n",
                    "id": "#star-alignreads.cwl/chimSegmentReadGapMax"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--clip3pAdapterMMp"
                    },
                    "doc": "double(s): max proportion of mismatches for 3p adpater clipping for each\nmate.  If one value is given, it will be assumed the same for both mates.\n",
                    "id": "#star-alignreads.cwl/clip3pAdapterMMp"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--clip3pAdapterSeq"
                    },
                    "doc": "string(s): adapter sequences to clip from 3p of each mate.  If one value is\ngiven, it will be assumed the same for both mates.\n",
                    "id": "#star-alignreads.cwl/clip3pAdapterSeq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--clip3pAfterAdapterNbases"
                    },
                    "doc": "int(s): number of bases to clip from 3p of each mate after the adapter\nclipping. If one value is given, it will be assumed the same for both\nmates.\n",
                    "id": "#star-alignreads.cwl/clip3pAfterAdapterNbases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--clip3pNbases"
                    },
                    "doc": "int(s): number(s) of bases to clip from 3p of each mate. If one value is\ngiven, it will be assumed the same for both mates.\n",
                    "id": "#star-alignreads.cwl/clip3pNbases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--clip5pNbases"
                    },
                    "doc": "int(s): number(s) of bases to clip from 5p of each mate. If one value is\ngiven, it will be assumed the same for both mates.\n",
                    "id": "#star-alignreads.cwl/clip5pNbases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeChrBinNbits"
                    },
                    "doc": "int: =log2(chrBin), where chrBin is the size of the bins for genome\nstorage: each chromosome will occupy an integer number of bins\n",
                    "id": "#star-alignreads.cwl/genomeChrBinNbits"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeDir"
                    },
                    "doc": "string: path to the directory where genome files are stored\n",
                    "id": "#star-alignreads.cwl/genomeDir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeLoad"
                    },
                    "doc": "NoSharedMemory\nstring: mode of shared memory usage for the genome files\nLoadAndKeep     ... load genome into shared and keep it in memory after run\nLoadAndRemove   ... load genome into shared but remove it after run\nLoadAndExit     ... load genome into shared memory and exit, keeping the genome in memory for future runs\nRemove          ... do not map anything, just remove loaded genome from memory\nNoSharedMemory  ... do not use shared memory, each job will have its own private copy of the genome\n",
                    "id": "#star-alignreads.cwl/genomeLoad"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSAindexNbases"
                    },
                    "doc": "int: length (bases) of the SA pre-indexing string. Typically between 10 and\n15. Longer strings will use much more memory, but allow faster searches.\n",
                    "id": "#star-alignreads.cwl/genomeSAindexNbases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSAsparseD"
                    },
                    "doc": "int>0: suffux array sparsity, i.e. distance between indices: use bigger\nnumbers to decrease needed RAM at the cost of mapping speed reduction\n",
                    "id": "#star-alignreads.cwl/genomeSAsparseD"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--inputBAMfile"
                    },
                    "doc": "string: path to BAM input file, to be used with --runMode\ninputAlignmentsFromBAM\n",
                    "id": "#star-alignreads.cwl/inputBAMfile"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitBAMsortRAM"
                    },
                    "doc": "int>=0: maximum available RAM for sorting BAM. If =0, it will be set to the\ngenome index size. 0 value can only be used with --genomeLoad\nNoSharedMemory option.\n",
                    "id": "#star-alignreads.cwl/limitBAMsortRAM"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitGenomeGenerateRAM"
                    },
                    "doc": "31000000000\nint>0: maximum available RAM (bytes) for genome generation\n",
                    "id": "#star-alignreads.cwl/limitGenomeGenerateRAM"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitIObufferSize"
                    },
                    "doc": "150000000\nint>0: max available buffers size (bytes) for input/output, per thread\n",
                    "id": "#star-alignreads.cwl/limitIObufferSize"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitOutSAMoneReadBytes"
                    },
                    "doc": "100000\nint>0: max size of the SAM record for one read. Recommended value: >(2*(LengthMate1+LengthMate2+100)*outFilterMultimapNmax\n",
                    "id": "#star-alignreads.cwl/limitOutSAMoneReadBytes"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitOutSJcollapsed"
                    },
                    "doc": "1000000\nint>0: max number of collapsed junctions\n",
                    "id": "#star-alignreads.cwl/limitOutSJcollapsed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitOutSJoneRead"
                    },
                    "doc": "1000\nint>0: max number of junctions for one read (including all multi-mappers)\n",
                    "id": "#star-alignreads.cwl/limitOutSJoneRead"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitSjdbInsertNsj"
                    },
                    "doc": "1000000\nint>=0: maximum number of junction to be inserted to the genome on the fly at\nthe mapping stage, including those from annotations and those detected in the\n1st step of the 2-pass run\n",
                    "id": "#star-alignreads.cwl/limitSjdbInsertNsj"
                },
                {
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outBAMcompression"
                    },
                    "doc": "int: -1 to 10  BAM compression level, -1=default compression (6?), 0=no\ncompression, 10=maximum compression\n",
                    "id": "#star-alignreads.cwl/outBAMcompression"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outBAMsortingThreadN"
                    },
                    "doc": "int: >=0: number of threads for BAM sorting. 0 will default to\nmin(6,--runThreadN).\n",
                    "id": "#star-alignreads.cwl/outBAMsortingThreadN"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFileNamePrefix",
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_name_prefix();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "string: output files name prefix (including full or relative path). Can\nonly be defined on the command line.\n",
                    "id": "#star-alignreads.cwl/outFileNamePrefix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterIntronMotifs"
                    },
                    "doc": "None\nstring: filter alignment using their motifs\nNone                           ... no filtering\nRemoveNoncanonical             ... filter out alignments that contain non-canonical junctions\nRemoveNoncanonicalUnannotated  ... filter out alignments that contain non-canonical unannotated junctions when using annotated splice junctions database. The annotated non-canonical junctions will be kept.\n",
                    "id": "#star-alignreads.cwl/outFilterIntronMotifs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMatchNmin"
                    },
                    "doc": "0\nint: alignment will be output only if the number of matched bases is higher\nthan this value\n",
                    "id": "#star-alignreads.cwl/outFilterMatchNmin"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMatchNminOverLread"
                    },
                    "doc": "0.66\nfloat: outFilterMatchNmin normalized to read length (sum of mates'' lengths\nfor paired-end reads)\n",
                    "id": "#star-alignreads.cwl/outFilterMatchNminOverLread"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMismatchNmax"
                    },
                    "doc": "10\nint: alignment will be output only if it has no more mismatches than this value\n",
                    "id": "#star-alignreads.cwl/outFilterMismatchNmax"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMismatchNoverLmax"
                    },
                    "doc": "float: alignment will be output only if its ratio of mismatches to *mapped* length is less than or equal to this value.\n",
                    "id": "#star-alignreads.cwl/outFilterMismatchNoverLmax"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMismatchNoverReadLmax"
                    },
                    "doc": "1\nfloat: alignment will be output only if its ratio of mismatches to *read* length\nis less than this value\n",
                    "id": "#star-alignreads.cwl/outFilterMismatchNoverReadLmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMultimapNmax"
                    },
                    "doc": "int: maximum number of loci the read is allowed to map to. Alignments (all of them) will be output only if\nthe read maps to no more loci than this value.\nOtherwise no alignments will be output, and the read will be counted as \"mapped to too many loci\"\nin the Log.final.out.\n",
                    "id": "#star-alignreads.cwl/outFilterMultimapNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterMultimapScoreRange"
                    },
                    "doc": "1\nint: the score range below the maximum score for multimapping alignments\n",
                    "id": "#star-alignreads.cwl/outFilterMultimapScoreRange"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterScoreMin"
                    },
                    "doc": "0\nint: alignment will be output only if its score is higher than or equal to this value\n",
                    "id": "#star-alignreads.cwl/outFilterScoreMin"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterScoreMinOverLread"
                    },
                    "doc": "0.66\nfloat: outFilterScoreMin normalized to read length (sum of mates'' lengths for\npaired-end reads)\n",
                    "id": "#star-alignreads.cwl/outFilterScoreMinOverLread"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFilterType"
                    },
                    "doc": "Normal\nstring: type of filtering\nNormal  ... standard filtering using only current alignment\nBySJout ... keep only those reads that contain junctions that passed filtering into SJ.out.tab\n",
                    "id": "#star-alignreads.cwl/outFilterType"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outMultimapperOrder"
                    },
                    "doc": "Old_2.4\nstring: order of multimapping alignments in the output files\nOld_2.4             ... quasi-random order used before 2.5.0\nRandom              ... random order of alignments for each multi-mapper. Read mates (pairs) are always adjacent, all alignment for each read stay together. This option will become default in the future releases.\n",
                    "id": "#star-alignreads.cwl/outMultimapperOrder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outQSconversionAdd"
                    },
                    "doc": "int: add this number to the quality score (e.g. to convert from Illumina to Sanger, use -31)\n",
                    "id": "#star-alignreads.cwl/outQSconversionAdd"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#star-alignreads.cwl/outReadsUnmapped/unmapped",
                            "symbols": [
                                "#star-alignreads.cwl/outReadsUnmapped/unmapped/None",
                                "#star-alignreads.cwl/outReadsUnmapped/unmapped/Fastx"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outReadsUnmapped"
                    },
                    "doc": "None\nstring: output of unmapped and partially mapped (i.e. mapped only one mate of a paired end read) reads in separate file(s).\nNone    ... no output\nFastx   ... output in separate fasta/fastq files, Unmapped.out.mate1/2\n",
                    "id": "#star-alignreads.cwl/outReadsUnmapped"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMattrIHstart"
                    },
                    "doc": "1\nint>=0:                     start value for the IH attribute. 0 may be required\nby some downstream software, such as Cufflinks or StringTie.\n",
                    "id": "#star-alignreads.cwl/outSAMattrIHstart"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMattrRGline"
                    },
                    "doc": "-\nstring(s): SAM/BAM read group line. The first word contains the read group identifier and must start with \"ID:\", e.g. --outSAMattrRGline ID:xxx CN:yy \"DS:z z z\".\nxxx will be added as RG tag to each output alignment. Any spaces in the tag values have to be double quoted.\nComma separated RG lines correspons to different (comma separated) input files in --readFilesIn. Commas have to be surrounded by spaces, e.g.\n--outSAMattrRGline ID:xxx , ID:zzz \"DS:z z\" , ID:yyy DS:yyyy\n",
                    "id": "#star-alignreads.cwl/outSAMattrRGline"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMattributes"
                    },
                    "doc": "Standard\nstring: a string of desired SAM attributes, in the order desired for the output SAM\nNH HI AS nM NM MD jM jI XS ch ... any combination in any order\nStandard   ... NH HI AS nM\nAll        ... NH HI AS nM NM MD jM jI ch\nNone       ... no attributes\n",
                    "id": "#star-alignreads.cwl/outSAMattributes"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMfilter"
                    },
                    "doc": "None\nstring(s): filter the output into main SAM/BAM files\nKeepOnlyAddedReferences ... only keep the reads for which all alignments are to the extra reference sequences added with --genomeFastaFiles at the mapping stage.\nKeepAllAddedReferences ...  keep all alignments to the extra reference sequences added with --genomeFastaFiles at the mapping stage.\n",
                    "id": "#star-alignreads.cwl/outSAMfilter"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMflagAND"
                    },
                    "doc": "65535\nint: 0 to 65535: sam FLAG will be bitwise AND''d with this value, i.e. FLAG=FLAG\n& outSAMflagOR. This is applied after all flags have been set by STAR, but before\noutSAMflagOR. Can be used to unset specific bits that are not set otherwise.\n",
                    "id": "#star-alignreads.cwl/outSAMflagAND"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMflagOR"
                    },
                    "doc": "int: 0 to 65535: sam FLAG will be bitwise OR'd with this value, i.e.\nFLAG=FLAG | outSAMflagOR. This is applied after all flags have been set by\nSTAR, and after outSAMflagAND. Can be used to set specific bits that are\nnot set otherwise.\n",
                    "id": "#star-alignreads.cwl/outSAMflagOR"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMheaderCommentFile"
                    },
                    "doc": "-\nstring: path to the file with @CO (comment) lines of the SAM header\n",
                    "id": "#star-alignreads.cwl/outSAMheaderCommentFile"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMheaderHD"
                    },
                    "doc": "-\nstrings: @HD (header) line of the SAM header\n",
                    "id": "#star-alignreads.cwl/outSAMheaderHD"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMheaderPG"
                    },
                    "doc": "-\nstrings: extra @PG (software) line of the SAM header (in addition to STAR)\n",
                    "id": "#star-alignreads.cwl/outSAMheaderPG"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMmapqUnique"
                    },
                    "doc": "255\nint: 0 to 255: the MAPQ value for unique mappers\n",
                    "id": "#star-alignreads.cwl/outSAMmapqUnique"
                },
                {
                    "type": "string",
                    "default": "Full",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMmode"
                    },
                    "doc": "string: mode of SAM output\nNone ... no SAM output\nFull ... full SAM output\nNoQS ... full SAM but without quality scores\n",
                    "id": "#star-alignreads.cwl/outSAMmode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMmultNmax"
                    },
                    "doc": "-1\nint: max number of multiple alignments for a read that will be output to the\nSAM/BAM files. -1 ... all alignments (up to --outFilterMultimapNmax) will be\noutput\n",
                    "id": "#star-alignreads.cwl/outSAMmultNmax"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMorder"
                    },
                    "doc": "Paired\nstring: type of sorting for the SAM output\nPaired: one mate after the other for all paired alignments\nPairedKeepInputOrder: one mate after the other for all paired alignments, the order is kept the same as in the input FASTQ files\n",
                    "id": "#star-alignreads.cwl/outSAMorder"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMprimaryFlag"
                    },
                    "doc": "OneBestScore\nstring: which alignments are considered primary - all others will be marked with 0x100 bit in the FLAG\nOneBestScore ... only one alignment with the best score is primary\nAllBestScore ... all alignments with the best score are primary\n",
                    "id": "#star-alignreads.cwl/outSAMprimaryFlag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMreadID"
                    },
                    "doc": "Standard\nstring: read ID record type\nStandard ... first word (until space) from the FASTx read ID line, removing /1,/2 from the end\nNumber   ... read number (index) in the FASTx file\n",
                    "id": "#star-alignreads.cwl/outSAMreadID"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMstrandField"
                    },
                    "doc": "None\nstring: Cufflinks-like strand field flag\nNone        ... not used\nintronMotif ... strand derived from the intron motif. Reads with inconsistent and/or non-canonical introns are filtered out.\n",
                    "id": "#star-alignreads.cwl/outSAMstrandField"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "BAM",
                        "Unsorted"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMtype"
                    },
                    "doc": "strings: type of SAM/BAM output\n1st word:\nBAM  ... output BAM without sorting\nSAM  ... output SAM without sorting\nNone ... no SAM/BAM output\n2nd, 3rd:\nUnsorted           ... standard unsorted\nSortedByCoordinate ... sorted by coordinate. This option will allocate extra memory for sorting which can be specified by --limitBAMsortRAM.\n",
                    "id": "#star-alignreads.cwl/outSAMtype"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSAMunmapped"
                    },
                    "doc": "string(s): output of unmapped reads in the SAM format\n  1st word:\n    None   ... no output\n    Within ... output unmapped reads within the main SAM file (i.e. Aligned.out.sam)\n  2nd word:\n    KeepPairs ... record unmapped mate for each alignment, and, in case of unsorted output, keep it adjacent to its mapped mate.\n    Only affects multi-mapping reads\n",
                    "id": "#star-alignreads.cwl/outSAMunmapped"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSJfilterCountTotalMin"
                    },
                    "doc": "3   1   1   1 \\n4 integers: minimum total (multi-mapping+unique) read count\nper junction for: (1) non-canonical motifs, (2) GT/AG and CT/AC motif, (3)\nGC/AG and CT/GC motif, (4) AT/AC and GT/AT motif. -1 means no output for that\nmotif\\nJunctions are output if one of outSJfilterCountUniqueMin OR outSJfilterCountTotalMin\nconditions are satisfied\\ndoes not apply to annotated junctions\n",
                    "id": "#star-alignreads.cwl/outSJfilterCountTotalMin"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSJfilterCountUniqueMin"
                    },
                    "doc": "3   1   1   1 \\n4 integers: minimum uniquely mapping read count per junction\nfor: (1) non-canonical motifs, (2) GT/AG and CT/AC motif, (3) GC/AG and CT/GC\nmotif, (4) AT/AC and GT/AT motif. -1 means no output for that motif\\nJunctions\nare output if one of outSJfilterCountUniqueMin OR outSJfilterCountTotalMin\nconditions are satisfied\\ndoes not apply to annotated junctions\n",
                    "id": "#star-alignreads.cwl/outSJfilterCountUniqueMin"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSJfilterDistToOtherSJmin"
                    },
                    "doc": "10  0   5   10\n4 integers>=0: minimum allowed distance to other junctions' donor/acceptor\ndoes not apply to annotated junctions\n",
                    "id": "#star-alignreads.cwl/outSJfilterDistToOtherSJmin"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSJfilterIntronMaxVsReadN"
                    },
                    "doc": "50000 100000 200000\nN integers>=0: maximum gap allowed for junctions supported by 1,2,3,,,N reads\ni.e. by default junctions supported by 1 read can have gaps <=50000b, by 2 reads: <=100000b, by 3 reads: <=200000. by >=4 reads any gap <=alignIntronMax\ndoes not apply to annotated junctions\n",
                    "id": "#star-alignreads.cwl/outSJfilterIntronMaxVsReadN"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSJfilterOverhangMin"
                    },
                    "doc": "30  12  12  12\n4 integers:    minimum overhang length for splice junctions on both sides for: (1) non-canonical motifs, (2) GT/AG and CT/AC motif, (3) GC/AG and CT/GC motif, (4) AT/AC and GT/AT motif. -1 means no output for that motif\ndoes not apply to annotated junctions\n",
                    "id": "#star-alignreads.cwl/outSJfilterOverhangMin"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outSJfilterReads"
                    },
                    "doc": "All\nstring: which reads to consider for collapsed splice junctions output\nAll: all reads, unique- and multi-mappers\nUnique: uniquely mapping reads only\n",
                    "id": "#star-alignreads.cwl/outSJfilterReads"
                },
                {
                    "type": "string",
                    "default": "Log",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outStd"
                    },
                    "doc": "Log\nstring: which output will be directed to stdout (standard out)\nLog                    ... log messages\nSAM                    ... alignments in SAM format (which normally are output to Aligned.out.sam file), normal standard output will go into Log.std.out\nBAM_Unsorted           ... alignments in BAM format, unsorted. Requires --outSAMtype BAM Unsorted\nBAM_SortedByCoordinate ... alignments in BAM format, unsorted. Requires --outSAMtype BAM SortedByCoordinate\nBAM_Quant              ... alignments to transcriptome in BAM format, unsorted. Requires --quantMode TranscriptomeSAM\n",
                    "id": "#star-alignreads.cwl/outStd"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outTmpDir"
                    },
                    "doc": "string: path to a directory that will be used as temporary by STAR. All contents of this directory will be removed!\n- the temp directory will default to outFileNamePrefix_STARtmp\n",
                    "id": "#star-alignreads.cwl/outTmpDir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outWigNorm"
                    },
                    "doc": "RPM\nstring: type of normalization for the signal\nRPM    ... reads per million of mapped reads\nNone   ... no normalization, \"raw\" counts\n",
                    "id": "#star-alignreads.cwl/outWigNorm"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outWigReferencesPrefix"
                    },
                    "doc": "string: prefix matching reference names to include in the output wiggle\nfile, e.g. \"chr\", default \"-\" - include all references\n",
                    "id": "#star-alignreads.cwl/outWigReferencesPrefix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outWigStrand"
                    },
                    "doc": "Stranded\nstring: strandedness of wiggle/bedGraph output\nStranded   ...  separate strands, str1 and str2\nUnstranded ...  collapsed strands\n",
                    "id": "#star-alignreads.cwl/outWigStrand"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outWigType"
                    },
                    "doc": "None\nstring(s): type of signal output, e.g. \"bedGraph\" OR \"bedGraph read1_5p\". Requires sorted BAM: --outSAMtype BAM SortedByCoordinate .\n1st word:\nNone       ... no signal output\nbedGraph   ... bedGraph format\nwiggle     ... wiggle format\n2nd word:\nread1_5p   ... signal from only 5' of the 1st read, useful for CAGE/RAMPAGE etc\nread2      ... signal from only 2nd read\n",
                    "id": "#star-alignreads.cwl/outWigType"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--parametersFiles"
                    },
                    "doc": "string: name of a user-defined parameters file, \"-\": none. Can only be\ndefined on the command line.\n",
                    "id": "#star-alignreads.cwl/parametersFiles"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--quantMode"
                    },
                    "doc": "-\nstring(s): types of quantification requested\n-                ... none\nTranscriptomeSAM ... output SAM/BAM alignments to transcriptome into a separate file\nGeneCounts       ... count reads per gene\n",
                    "id": "#star-alignreads.cwl/quantMode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--quantTranscriptomeBAMcompression"
                    },
                    "doc": "int: -1 to 10  transcriptome BAM compression level, -1=default compression\n(6?), 0=no compression, 10=maximum compression\n",
                    "id": "#star-alignreads.cwl/quantTranscriptomeBAMcompression"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--quantTranscriptomeBan"
                    },
                    "doc": "IndelSoftclipSingleend\nstring: prohibit various alignment type\nIndelSoftclipSingleend  ... prohibit indels, soft clipping and single-end alignments - compatible with RSEM\nSingleend               ... prohibit single-end alignments\n",
                    "id": "#star-alignreads.cwl/quantTranscriptomeBan"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--readFilesCommand"
                    },
                    "doc": "string(s): command line to execute for each of the input file. This command should generate FASTA or FASTQ text and send it to stdout\nFor example: zcat - to uncompress .gz files, bzcat - to uncompress .bz2 files, etc.\n",
                    "id": "#star-alignreads.cwl/readFilesCommand"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--readFilesIn"
                    },
                    "doc": "string(s): paths to files that contain input read1 (and, if needed,  read2)\n",
                    "id": "#star-alignreads.cwl/readFilesIn"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--readMapNumber"
                    },
                    "doc": "-1\nint: number of reads to map from the beginning of the file\n-1: map all reads\n",
                    "id": "#star-alignreads.cwl/readMapNumber"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--readMatesLengthsIn"
                    },
                    "doc": "string: Equal/NotEqual - lengths of names,sequences,qualities for both\nmates are the same  / not the same. NotEqual is safe in all situations.\n",
                    "id": "#star-alignreads.cwl/readMatesLengthsIn"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--readNameSeparator"
                    },
                    "doc": "string(s): character(s) separating the part of the read names that will be\ntrimmed in output (read name after space is always trimmed)\n",
                    "id": "#star-alignreads.cwl/readNameSeparator"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runDirPerm"
                    },
                    "doc": "User_RWX\nstring: permissions for the directories created at the run-time.\nUser_RWX ... user-read/write/execute\nAll_RWX  ... all-read/write/execute (same as chmod 777)\n",
                    "id": "#star-alignreads.cwl/runDirPerm"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runRNGseed"
                    },
                    "doc": "777\nint: random number generator seed.\n",
                    "id": "#star-alignreads.cwl/runRNGseed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreDelBase"
                    },
                    "doc": "-2\ndeletion extension penalty per base (in addition to scoreDelOpen)\n",
                    "id": "#star-alignreads.cwl/scoreDelBase"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreDelOpen"
                    },
                    "doc": "-2\ndeletion open penalty\n",
                    "id": "#star-alignreads.cwl/scoreDelOpen"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreGap"
                    },
                    "doc": "0\nint: splice junction penalty (independent on intron motif)\n",
                    "id": "#star-alignreads.cwl/scoreGap"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreGapATAC"
                    },
                    "doc": "-8\nAT/AC  and GT/AT junction penalty  (in addition to scoreGap)\n",
                    "id": "#star-alignreads.cwl/scoreGapATAC"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreGapGCAG"
                    },
                    "doc": "-4\nGC/AG and CT/GC junction penalty (in addition to scoreGap)\n",
                    "id": "#star-alignreads.cwl/scoreGapGCAG"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreGapNoncan"
                    },
                    "doc": "-8\nint: non-canonical junction penalty (in addition to scoreGap)\n",
                    "id": "#star-alignreads.cwl/scoreGapNoncan"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreGenomicLengthLog2scale"
                    },
                    "doc": "-0.25\nextra score logarithmically scaled with genomic length of the alignment: scoreGenomicLengthLog2scale*log2(genomicLength)\n",
                    "id": "#star-alignreads.cwl/scoreGenomicLengthLog2scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreInsBase"
                    },
                    "doc": "-2\ninsertion extension penalty per base (in addition to scoreInsOpen)\n",
                    "id": "#star-alignreads.cwl/scoreInsBase"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreInsOpen"
                    },
                    "doc": "-2\ninsertion open penalty\n",
                    "id": "#star-alignreads.cwl/scoreInsOpen"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scoreStitchSJshift"
                    },
                    "doc": "1\nmaximum score reduction while searching for SJ boundaries inthe stitching step\n",
                    "id": "#star-alignreads.cwl/scoreStitchSJshift"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedMultimapNmax"
                    },
                    "doc": "10000\nint>0: only pieces that map fewer than this value are utilized in the stitching\nprocedure\n",
                    "id": "#star-alignreads.cwl/seedMultimapNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedNoneLociPerWindow"
                    },
                    "doc": "10\nnint>0: max number of one seed loci per window\n",
                    "id": "#star-alignreads.cwl/seedNoneLociPerWindow"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedPerReadNmax"
                    },
                    "doc": "1000\nint>0: max number of seeds per read\n",
                    "id": "#star-alignreads.cwl/seedPerReadNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedPerWindowNmax"
                    },
                    "doc": "50\nint>0: max number of seeds per window\n",
                    "id": "#star-alignreads.cwl/seedPerWindowNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedSearchLmax"
                    },
                    "doc": "0\nint>=0: defines the maximum length of the seeds, if =0 max seed lengthis infinite\n",
                    "id": "#star-alignreads.cwl/seedSearchLmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedSearchStartLmax"
                    },
                    "doc": "50\nint>0: defines the search start point through the read - the read is split into\npieces no longer than this value\n",
                    "id": "#star-alignreads.cwl/seedSearchStartLmax"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedSearchStartLmaxOverLread"
                    },
                    "doc": "1.0\nfloat: seedSearchStartLmax normalized to read length (sum of mates'' lengths\nfor paired-end reads)\n",
                    "id": "#star-alignreads.cwl/seedSearchStartLmaxOverLread"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbFileChrStartEnd"
                    },
                    "doc": "string(s): path to the files with genomic coordinates (chr <tab> start <tab>\nend <tab> strand) for the splice junction introns. Multiple files can be supplied\nwand will be concatenated.\n",
                    "id": "#star-alignreads.cwl/sjdbFileChrStartEnd"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFchrPrefix"
                    },
                    "doc": "string: prefix for chromosome names in a GTF file (e.g. 'chr' for using\nENSMEBL annotations with UCSC geneomes)\n",
                    "id": "#star-alignreads.cwl/sjdbGTFchrPrefix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFfeatureExon"
                    },
                    "doc": "exon\nstring: feature type in GTF file to be used as exons for building\ntranscripts\n",
                    "id": "#star-alignreads.cwl/sjdbGTFfeatureExon"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFfile"
                    },
                    "doc": "string: path to the GTF file with annotations\n",
                    "id": "#star-alignreads.cwl/sjdbGTFfile"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFtagExonParentGene"
                    },
                    "doc": "gene_id\nstring: tag name to be used as exons'' gene-parents (default \"gene_id\" works\nfor GTF files)\n",
                    "id": "#star-alignreads.cwl/sjdbGTFtagExonParentGene"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFtagExonParentTranscript"
                    },
                    "doc": "transcript_id\nstring: tag name to be used as exons' transcript-parents (default\n\"transcript_id\" works for GTF files)\n",
                    "id": "#star-alignreads.cwl/sjdbGTFtagExonParentTranscript"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbInsertSave"
                    },
                    "doc": "Basic\nstring: which files to save when sjdb junctions are inserted on the fly at the mapping step\nBasic ... only small junction / transcript files\nAll   ... all files including big Genome, SA and SAindex - this will create a complete genome directory\n",
                    "id": "#star-alignreads.cwl/sjdbInsertSave"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbOverhang"
                    },
                    "doc": "100\nint>0: length of the donor/acceptor sequence on each side of the junctions,\nideally = (mate_length - 1)\n",
                    "id": "#star-alignreads.cwl/sjdbOverhang"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbScore"
                    },
                    "doc": "2\nint: extra alignment score for alignmets that cross database junctions\n",
                    "id": "#star-alignreads.cwl/sjdbScore"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sysShell"
                    },
                    "doc": "string: path to the shell binary, preferrably bash, e.g. /bin/bash.\n- ... the default shell is executed, typically /bin/sh. This was reported to fail on some Ubuntu systems - then you need to specify path to bash.\n",
                    "id": "#star-alignreads.cwl/sysShell"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runThreadN"
                    },
                    "doc": "1\nint: number of threads to run STAR\n",
                    "id": "#star-alignreads.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--twopass1readsN"
                    },
                    "doc": "int: number of reads to process for the 1st step. Use very large number (or\ndefault -1) to map all reads in the first step.\n",
                    "id": "#star-alignreads.cwl/twopass1readsN"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--twopassMode"
                    },
                    "doc": "None\nstring: 2-pass mapping mode.\nNone        ... 1-pass mapping\nBasic       ... basic 2-pass mapping, with all 1st pass junctions inserted into the genome indices on the fly\n",
                    "id": "#star-alignreads.cwl/twopassMode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--winAnchorDistNbins"
                    },
                    "doc": "9\nint>0: max number of bins between two anchors that allows aggregation of anchors\ninto one window\n",
                    "id": "#star-alignreads.cwl/winAnchorDistNbins"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--winAnchorMultimapNmax"
                    },
                    "doc": "50\nint>0: max number of loci anchors are allowed to map to\n",
                    "id": "#star-alignreads.cwl/winAnchorMultimapNmax"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--winBinNbits"
                    },
                    "doc": "16\nint>0: =log2(winBin), where winBin is the size of the bin for the windows/clustering,\neach window will occupy an integer number of bins.\n",
                    "id": "#star-alignreads.cwl/winBinNbits"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--winFlankNbins"
                    },
                    "doc": "4\nint>0: log2(winFlank), where win Flank is the size of the left and right flanking\nregions for each window\n",
                    "id": "#star-alignreads.cwl/winFlankNbins"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--winReadCoverageBasesMin"
                    },
                    "doc": "int>0: minimum number of bases covered by the seeds in a window , for STARlong algorithm only.\n",
                    "id": "#star-alignreads.cwl/winReadCoverageBasesMin"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--winReadCoverageRelativeMin"
                    },
                    "doc": "float>=0: minimum relative coverage of the read sequence by the seeds in a window, for STARlong algorithm only.\n",
                    "id": "#star-alignreads.cwl/winReadCoverageRelativeMin"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*Aligned.out*"
                    },
                    "id": "#star-alignreads.cwl/aligned_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Log.final.out*"
                    },
                    "id": "#star-alignreads.cwl/log_final"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Log.out*"
                    },
                    "id": "#star-alignreads.cwl/log_out"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Log.progress.out*"
                    },
                    "id": "#star-alignreads.cwl/log_progress"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*SJ.out.tab*"
                    },
                    "id": "#star-alignreads.cwl/log_sj"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Log.std.out*"
                    },
                    "id": "#star-alignreads.cwl/log_std"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "*Log.final.out*",
                        "outputEval": "${\n  let uniquelyMappedReadsNumberRegex = /Uniquely mapped reads number.*/;\n  return parseInt(self[0].contents.match(uniquelyMappedReadsNumberRegex)[0].split(/\\|\\t/g)[1]);\n}\n"
                    },
                    "id": "#star-alignreads.cwl/uniquely_mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Unmapped.out.mate1*"
                    },
                    "id": "#star-alignreads.cwl/unmapped_mate_1_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Unmapped.out.mate2*"
                    },
                    "id": "#star-alignreads.cwl/unmapped_mate_2_file"
                }
            ],
            "baseCommand": [
                "STAR"
            ],
            "arguments": [
                "--runMode",
                "alignReads"
            ],
            "doc": "Tool runs STAR alignReads.\n\n`default_output_name_prefix` function returns output files prefix if `outFileNamePrefix` is not set. By default prefix\nis equal to basename of `readFilesIn`.\n",
            "id": "#star-alignreads.cwl",
            "http://schema.org/name": "star-alignreads",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/star-alignreads.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#star-metadata.yaml",
                "http://schema.org/name": "STAR",
                "http://schema.org/about": "Aligns RNA-seq reads to a reference genome using uncompressed suffix arrays.\nSTAR has a potential for accurately aligning long (several kilobases) reads that\nare emerging from the third-generation sequencing technologies\n",
                "http://schema.org/url": "https://github.com/alexdobin/STAR",
                "http://schema.org/codeRepository": "https://github.com/alexdobin/STAR",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v2.5.3a",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#star-metadata.yaml/ 10.1093/bioinformatics/bts635",
                        "datePublished": "1 January 2013",
                        "http://schema.org/name": "STAR: ultrafast universal RNA-seq aligner",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Alexander Dobin"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Carrie A. Davis"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Felix Schlesinger"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Jorg Drenkow"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Chris Zaleski"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Sonali Jha"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Philippe Batut"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Mark Chaisson"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Thomas R. Gingeras1"
                            }
                        ],
                        "http://schema.org/url": "https://academic.oup.com/bioinformatics/article/29/1/15/272537"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/alexdobin/STAR/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cold Spring Harbor Laboratory, Cold Spring Harbor, NY, USA",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Alexander Dobin",
                                "http://schema.org/description": "main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: STAR  [options]... --genomeDir REFERENCE   --readFilesIn R1.fq R2.fq\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { let basename = inputs.bedgraph_file.location.split('/').slice(-1)[0]; let root = basename.split('.').slice(0,-1).join('.'); let ext = \".bigWig\"; return (root == \"\")?basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/ucscuserapps:v358"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10
                    },
                    "doc": "Four column bedGraph file: <chrom> <start> <end> <value>\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/bedgraph_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "separate": false,
                        "position": 7,
                        "prefix": "-blockSize="
                    },
                    "doc": "Number of items to bundle in r-tree.  Default 256\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/block_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 11
                    },
                    "doc": "Two-column chromosome length file: <chromosome name> <size in bases>\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "separate": false,
                        "position": 6,
                        "prefix": "-itemsPerSlot="
                    },
                    "doc": "Number of data points bundled at lowest level. Default 1024\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/items_per_slot"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "If set, writes the output bigWig file to output_filename,\notherwise generates filename from default_output_filename()\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-unc"
                    },
                    "doc": "Disable compression\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/unc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename();\n    } else {\n      return inputs.output_filename;\n    }\n}\n"
                    },
                    "id": "#ucsc-bedgraphtobigwig.cwl/bigwig_file"
                }
            ],
            "baseCommand": [
                "bedGraphToBigWig"
            ],
            "doc": "Tool converts bedGraph to bigWig file.\n\n`default_output_filename` function returns filename for generated bigWig if `output_filename` is not provided.\nDefault filename is generated on the base of `bedgraph_file` basename with the updated to `*.bigWig` extension.\n",
            "id": "#ucsc-bedgraphtobigwig.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#ucsc-metadata.yaml",
                "http://schema.org/name": "UCSC userApps",
                "http://schema.org/about": "UCSC genome browser bioinformatic utilities\n",
                "http://schema.org/url": "https://genome.ucsc.edu/util.html",
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v358",
                    "http://schema.org/applicationCategory": "commandline tool",
                    "http://schema.org/downloadURL": "http://hgdownload.cse.ucsc.edu/admin/exe/userApps.v358.src.tgz"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ]
            },
            "http://schema.org/name": "ucsc-bedgraphtobigwig",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/ucsc-bedgraphtobigwig.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage:\n   bedGraphToBigWig in.bedGraph chrom.sizes out.bw\nwhere in.bedGraph is a four column file in the format:\n      <chrom> <start> <end> <value>\nand chrom.sizes is a two-column file/URL: <chromosome name> <size in bases>\nand out.bw is the output indexed big wig file.\nIf the assembly <db> is hosted by UCSC, chrom.sizes can be a URL like\n  http://hgdownload.cse.ucsc.edu/goldenPath/<db>/bigZips/<db>.chrom.sizes\nor you may use the script fetchChromSizes to download the chrom.sizes file.\nIf not hosted by UCSC, a chrom.sizes file can be generated by running\ntwoBitInfo on the assembly .2bit file.\nThe input bedGraph file must be sorted, use the unix sort command:\n  sort -k1,1 -k2,2n unsorted.bedGraph > sorted.bedGraph\noptions:\n   -blockSize=N - Number of items to bundle in r-tree.  Default 256\n   -itemsPerSlot=N - Number of data points bundled at lowest level. Default 1024\n   -unc - If set, do not use compression.\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:metadata": [
                "../metadata/rnaseq-header.cwl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Chromosome length file for reference genome",
                    "format": "http://edamontology.org/format_2330",
                    "doc": "Chromosome length file for reference genome",
                    "id": "#main/chrom_length_file"
                },
                {
                    "type": "File",
                    "label": "FASTQ 2 input file",
                    "format": "http://edamontology.org/format_1930",
                    "doc": "Reads data in a FASTQ format, received after paired end sequencing",
                    "id": "#main/fastq_file_downstream"
                },
                {
                    "type": "File",
                    "label": "FASTQ 1 input file",
                    "format": "http://edamontology.org/format_1930",
                    "doc": "Reads data in a FASTQ format, received after paired end sequencing",
                    "id": "#main/fastq_file_upstream"
                },
                {
                    "type": "File",
                    "label": "HAL file",
                    "format": "http://edamontology.org/format_3590",
                    "doc": "HAL file that includes strain information",
                    "id": "#main/hal_file"
                },
                {
                    "type": "Directory",
                    "label": "STAR indices folder for insilico genome",
                    "doc": "Path to STAR generated indices for insilico genome",
                    "id": "#main/insilico_star_indices_folder"
                },
                {
                    "type": "string",
                    "label": "Reference strain name",
                    "doc": "Reference strain name to be projected to",
                    "id": "#main/ref_strain"
                },
                {
                    "type": "Directory",
                    "label": "STAR indices folder for reference genome",
                    "doc": "Path to STAR generated indices for reference genome",
                    "id": "#main/star_indices_folder"
                },
                {
                    "type": "string",
                    "label": "I strain name",
                    "doc": "First strain name",
                    "id": "#main/strain1"
                },
                {
                    "type": "string",
                    "label": "II strain name",
                    "doc": "Second strain name",
                    "id": "#main/strain2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR final log for insilico genome",
                    "doc": "STAR Log.final.out for insilico genome",
                    "outputSource": "#main/allele_alignreads_se_pe/insilico_star_final_log",
                    "id": "#main/insilico_star_final_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR log out for insilico genome",
                    "doc": "STAR Log.out for insilico genome",
                    "outputSource": "#main/allele_alignreads_se_pe/insilico_star_out_log",
                    "id": "#main/insilico_star_out_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR progress log for insilico genome",
                    "doc": "STAR Log.progress.out for insilico genome",
                    "outputSource": "#main/allele_alignreads_se_pe/insilico_star_progress_log",
                    "id": "#main/insilico_star_progress_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR stdout log for insilico genome",
                    "doc": "STAR Log.std.out for insilico genome",
                    "outputSource": "#main/allele_alignreads_se_pe/insilico_star_stdout_log",
                    "id": "#main/insilico_star_stdout_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Reference coordinate sorted BAM alignment file (+index BAI)",
                    "doc": "Coordinate sorted BAM file and BAI index file for reference genome",
                    "outputSource": "#main/allele_alignreads_se_pe/reference_bambai_pair",
                    "id": "#main/reference_bambai_pair"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3006",
                    "label": "Reference bigWig file",
                    "doc": "Generated BigWig file for the reference genome",
                    "outputSource": "#main/allele_alignreads_se_pe/reference_bigwig",
                    "id": "#main/reference_bigwig"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR final log for reference genome",
                    "doc": "STAR Log.final.out for reference genome",
                    "outputSource": "#main/allele_alignreads_se_pe/reference_star_final_log",
                    "id": "#main/reference_star_final_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR log out for reference genome",
                    "doc": "STAR Log.out for reference genome",
                    "outputSource": "#main/allele_alignreads_se_pe/reference_star_out_log",
                    "id": "#main/reference_star_out_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR progress log for reference genome",
                    "doc": "STAR Log.progress.out for reference genome",
                    "outputSource": "#main/allele_alignreads_se_pe/reference_star_progress_log",
                    "id": "#main/reference_star_progress_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2330",
                    "label": "STAR stdout log for reference genome",
                    "doc": "STAR Log.std.out for reference genome",
                    "outputSource": "#main/allele_alignreads_se_pe/reference_star_stdout_log",
                    "id": "#main/reference_star_stdout_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Strain I coordinate sorted BAM alignment file (+index BAI)",
                    "doc": "Coordinate sorted BAM file and BAI index file for strain I",
                    "outputSource": "#main/allele_alignreads_se_pe/strain1_bambai_pair",
                    "id": "#main/strain1_bambai_pair"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3006",
                    "label": "I strain bigWig file",
                    "doc": "Generated bigWig file for the first strain",
                    "outputSource": "#main/allele_alignreads_se_pe/strain1_bigwig",
                    "id": "#main/strain1_bigwig"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Strain II coordinate sorted BAM alignment file (+index BAI)",
                    "doc": "Coordinate sorted BAM file and BAI index file for strain II",
                    "outputSource": "#main/allele_alignreads_se_pe/strain2_bambai_pair",
                    "id": "#main/strain2_bambai_pair"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3006",
                    "label": "II strain bigWig file",
                    "doc": "Generated bigWig file for the second strain",
                    "outputSource": "#main/allele_alignreads_se_pe/strain2_bigwig",
                    "id": "#main/strain2_bigwig"
                }
            ],
            "steps": [
                {
                    "run": "#allele-alignreads-se-pe.cwl",
                    "in": [
                        {
                            "source": "#main/chrom_length_file",
                            "id": "#main/allele_alignreads_se_pe/chrom_length_file"
                        },
                        {
                            "source": [
                                "#main/extract_fastq_upstream/fastq_file",
                                "#main/extract_fastq_downstream/fastq_file"
                            ],
                            "id": "#main/allele_alignreads_se_pe/fastq_files"
                        },
                        {
                            "source": "#main/hal_file",
                            "id": "#main/allele_alignreads_se_pe/hal_file"
                        },
                        {
                            "source": "#main/insilico_star_indices_folder",
                            "id": "#main/allele_alignreads_se_pe/insilico_star_indices_folder"
                        },
                        {
                            "source": "#main/ref_strain",
                            "id": "#main/allele_alignreads_se_pe/ref_strain"
                        },
                        {
                            "source": "#main/star_indices_folder",
                            "id": "#main/allele_alignreads_se_pe/reference_star_indices_folder"
                        },
                        {
                            "source": "#main/strain1",
                            "id": "#main/allele_alignreads_se_pe/strain1"
                        },
                        {
                            "source": "#main/strain2",
                            "id": "#main/allele_alignreads_se_pe/strain2"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/allele_alignreads_se_pe/threads"
                        }
                    ],
                    "out": [
                        "#main/allele_alignreads_se_pe/strain1_bambai_pair",
                        "#main/allele_alignreads_se_pe/strain2_bambai_pair",
                        "#main/allele_alignreads_se_pe/reference_bambai_pair",
                        "#main/allele_alignreads_se_pe/strain1_bigwig",
                        "#main/allele_alignreads_se_pe/strain2_bigwig",
                        "#main/allele_alignreads_se_pe/reference_bigwig",
                        "#main/allele_alignreads_se_pe/insilico_star_final_log",
                        "#main/allele_alignreads_se_pe/insilico_star_out_log",
                        "#main/allele_alignreads_se_pe/insilico_star_progress_log",
                        "#main/allele_alignreads_se_pe/insilico_star_stdout_log",
                        "#main/allele_alignreads_se_pe/reference_star_final_log",
                        "#main/allele_alignreads_se_pe/reference_star_out_log",
                        "#main/allele_alignreads_se_pe/reference_star_progress_log",
                        "#main/allele_alignreads_se_pe/reference_star_stdout_log"
                    ],
                    "id": "#main/allele_alignreads_se_pe"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_file_downstream",
                            "id": "#main/extract_fastq_downstream/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastq_downstream/fastq_file"
                    ],
                    "id": "#main/extract_fastq_downstream"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_file_upstream",
                            "id": "#main/extract_fastq_upstream/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastq_upstream/fastq_file"
                    ],
                    "id": "#main/extract_fastq_upstream"
                }
            ],
            "label": "RNA-seq alelle specific pipeline for paired-end data",
            "doc": "Allele specific RNA-Seq paired-end workflow\n",
            "id": "#main",
            "http://schema.org/name": "RNA-seq alelle specific pipeline for paired-end data",
            "http://schema.org/alternateName": "Allele specific RNA-Seq paired-end workflow",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/allele-rnaseq-pe.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
